Module ai

Module ai 

AI module — Behavior Trees, Utility AI, Goal-Oriented Action Planning, Pathfinding, Navigation Meshes, Flow Fields, Steering Behaviors, and Blackboard.

Re-exports

pub use pathfinding::PathGrid;
pub use pathfinding::PathNode;
pub use pathfinding::AStarPathfinder;
pub use pathfinding::JumpPointSearch;
pub use pathfinding::DijkstraMap;
pub use pathfinding::HierarchicalPathfinder;
pub use pathfinding::Path;
pub use pathfinding::PathRequest;
pub use pathfinding::PathResult;
pub use pathfinding::PathfindingStats;
pub use pathfinding::Heuristic;
pub use pathfinding::smooth_path;
pub use pathfinding::spline_path;
pub use navmesh::NavMesh;
pub use navmesh::NavVertex;
pub use navmesh::NavTriangle;
pub use navmesh::Portal;
pub use navmesh::NavMeshAgent;
pub use navmesh::NavMeshBuilder;
pub use navmesh::AabbObstacle;
pub use navmesh::BatchPathQuery;
pub use navmesh::NavMeshSpatialHash;
pub use flowfield::FlowField;
pub use flowfield::FlowFieldCache;
pub use flowfield::FlowFieldGroup;
pub use flowfield::FlowFieldAgent;
pub use flowfield::Flock;
pub use flowfield::Boid;
pub use flowfield::DynamicObstacleField;
pub use steering::SteeringAgent;
pub use steering::SteeringBehavior;
pub use steering::WeightedSteering;
pub use steering::PrioritySteeringCombiner;
pub use steering::SteeringSystem;
pub use steering::ContextMap;
pub use steering::KinematicAgent;
pub use steering::seek;
pub use steering::flee;
pub use steering::arrive;
pub use steering::pursuit;
pub use steering::evade;
pub use steering::wander;
pub use steering::obstacle_avoidance;
pub use steering::wall_avoidance;
pub use steering::path_following;
pub use steering::separation;
pub use steering::alignment;
pub use steering::cohesion;
pub use steering::leader_following;
pub use steering::queue;
pub use steering::interpose;
pub use blackboard::Blackboard;
pub use blackboard::BlackboardEntry;
pub use blackboard::BlackboardValue;
pub use blackboard::SharedBlackboard;
pub use blackboard::BlackboardCondition;
pub use blackboard::BlackboardObserver;

Modules

behavior_tree
Behavior Tree system — full implementation with composites, decorators, actions, conditions, blackboard, and a fluent builder DSL.
blackboard
Shared AI knowledge base — the Blackboard pattern.
flowfield
Flow field pathfinding and Reynolds flocking for large groups of agents.
goap
Goal-Oriented Action Planning (GOAP).
navmesh
Navigation mesh system for polygon-based pathfinding.
pathfinding
A* pathfinding, Dijkstra maps, Jump Point Search, and hierarchical pathfinding.
steering
Steering behaviors for autonomous agents.
utility
Utility AI — scoring-based decision making.