pub enum BlackboardCondition {
HasKey(String),
NotHasKey(String),
KeyEquals(String, BlackboardValue),
KeyGreaterThan(String, f64),
KeyLessThan(String, f64),
KeyInRange(String, f64, f64),
IsTrue(String),
IsFalse(String),
And(Box<BlackboardCondition>, Box<BlackboardCondition>),
Or(Box<BlackboardCondition>, Box<BlackboardCondition>),
Not(Box<BlackboardCondition>),
}Expand description
A condition that can be evaluated against a Blackboard.
Primarily for use in behavior tree guard nodes.
Variants
HasKey(String)
True if the key exists (and has not expired).
NotHasKey(String)
True if the key does NOT exist (or has expired).
KeyEquals(String, BlackboardValue)
True if the value at key equals the given BlackboardValue.
KeyGreaterThan(String, f64)
True if the numeric value at key is strictly greater than threshold.
KeyLessThan(String, f64)
True if the numeric value at key is strictly less than threshold.
KeyInRange(String, f64, f64)
True if the numeric value at key is >= min and <= max.
IsTrue(String)
True if the boolean at key is true.
IsFalse(String)
True if the boolean at key is false (or absent).
And(Box<BlackboardCondition>, Box<BlackboardCondition>)
Logical AND of two conditions.
Or(Box<BlackboardCondition>, Box<BlackboardCondition>)
Logical OR of two conditions.
Not(Box<BlackboardCondition>)
Logical NOT of a condition.
Implementations
Sourceimpl BlackboardCondition
impl BlackboardCondition
Sourcepub fn evaluate(&self, bb: &Blackboard) -> bool
pub fn evaluate(&self, bb: &Blackboard) -> bool
Evaluate this condition against the given blackboard.
pub fn and(self, other: BlackboardCondition) -> BlackboardCondition
pub fn or(self, other: BlackboardCondition) -> BlackboardCondition
pub fn not(self) -> BlackboardCondition