pub struct BlackboardEntry {
pub value: BlackboardValue,
pub timestamp: f64,
pub ttl: Option<f64>,
}Expand description
A single entry on the blackboard, with optional expiry.
Fields
value: BlackboardValuetimestamp: f64Simulated time when this entry was written.
ttl: Option<f64>Optional time-to-live in seconds. None = permanent.
Implementations
Sourceimpl BlackboardEntry
impl BlackboardEntry
pub fn new(value: BlackboardValue, timestamp: f64) -> Self
pub fn with_ttl(self, ttl: f64) -> Self
Sourcepub fn is_expired(&self, now: f64) -> bool
pub fn is_expired(&self, now: f64) -> bool
Returns true if this entry has expired at time now.
Sourcepub fn remaining_ttl(&self, now: f64) -> f64
pub fn remaining_ttl(&self, now: f64) -> f64
Remaining time-to-live; returns 0.0 if already expired.