pub struct BlackboardObserver { /* private fields */ }Expand description
A simple change-notification system for the blackboard.
Implementations
Sourceimpl BlackboardObserver
impl BlackboardObserver
pub fn new() -> Self
Sourcepub fn poll(&mut self, bb: &Blackboard)
pub fn poll(&mut self, bb: &Blackboard)
Poll the blackboard for changes to watched keys.
Sourcepub fn drain_changes(&mut self) -> Vec<String>
pub fn drain_changes(&mut self) -> Vec<String>
Returns and clears the list of changed keys since last poll.
Sourcepub fn has_changed(&self, key: &str) -> bool
pub fn has_changed(&self, key: &str) -> bool
Check whether a key changed in the last poll.