Goal-Oriented Action Planning (GOAP).
Each agent has a world state (map of bool conditions), a goal state, and a set of actions with preconditions and effects. The planner uses A* to find the cheapest sequence of actions that transforms current state into goal state.
Structs
- Goap
Action - An action that can be taken by a GOAP agent.
- Goap
Agent - A runtime GOAP agent that re-plans when its goal or state changes.
- Goap
Planner - Plans a sequence of actions to reach goal state from current state.
- World
State - A set of named boolean conditions describing world state.
Enums
Functions
- guard_
actions - Patrol and investigation actions.
- melee_
combat_ actions - Standard combat actions for a melee fighter.