pub struct WorldState(/* private fields */);Expand description
A set of named boolean conditions describing world state.
Implementations
Sourceimpl WorldState
impl WorldState
pub fn new() -> Self
pub fn set(&mut self, key: &str, value: bool)
pub fn get(&self, key: &str) -> bool
Sourcepub fn satisfies(&self, goal: &WorldState) -> bool
pub fn satisfies(&self, goal: &WorldState) -> bool
Check if this state satisfies all conditions in goal.
Sourcepub fn apply(&self, effects: &WorldState) -> WorldState
pub fn apply(&self, effects: &WorldState) -> WorldState
Apply an action’s effects, returning a new state.
Sourcepub fn distance_to(&self, goal: &WorldState) -> usize
pub fn distance_to(&self, goal: &WorldState) -> usize
Distance heuristic: number of conditions in goal not satisfied.