pub fn evade(agent: &SteeringAgent, threat_pos: Vec2, threat_vel: Vec2) -> Vec2Expand description
Evade: flee from the predicted future position of a threat.
pub fn evade(agent: &SteeringAgent, threat_pos: Vec2, threat_vel: Vec2) -> Vec2Evade: flee from the predicted future position of a threat.