pub fn interpose(agent: &SteeringAgent, a: Vec2, b: Vec2) -> Vec2Expand description
Interpose: steer to a position between two points a and b.
pub fn interpose(agent: &SteeringAgent, a: Vec2, b: Vec2) -> Vec2Interpose: steer to a position between two points a and b.