pub struct SteeringSystem {
pub agents: Vec<SteeringAgent>,
pub behaviors: Vec<WeightedSteering>,
}Expand description
Manages a list of agents and updates them each frame.
Fields
agents: Vec<SteeringAgent>behaviors: Vec<WeightedSteering>Implementations
Sourceimpl SteeringSystem
impl SteeringSystem
pub fn new() -> Self
pub fn add_agent( &mut self, agent: SteeringAgent, behavior: WeightedSteering, ) -> usize
Sourcepub fn nearest_agent(&self, pos: Vec2) -> Option<usize>
pub fn nearest_agent(&self, pos: Vec2) -> Option<usize>
Returns the index of the agent nearest to pos.
pub fn agent_count(&self) -> usize