BlendShapeAnimator

Struct BlendShapeAnimator 

pub struct BlendShapeAnimator {
    pub time: f32,
    pub speed: f32,
    /* private fields */
}
Drives blend-shape weights via time-varying F32 keyframe tracks.

Fields

time: f32

Current playback time (seconds).

speed: f32

Implementations

Source

impl BlendShapeAnimator

pub fn new() -> Self

pub fn add_track(&mut self, shape_name: impl Into<String>, keys: Vec<F32Key>)

Add a weight track for a named blend shape.

pub fn advance(&mut self, dt: f32)

Advance time by dt seconds.

pub fn evaluate(&self) -> HashMap<String, f32>

Evaluate all tracks at current time and return a weight map.

pub fn weight_of(&self, shape_name: &str) -> f32

Evaluate a single shape weight at current time.

pub fn track_count(&self) -> usize

Number of shape tracks.