pub fn add_output(
base: &AnimationOutput,
additive: &AnimationOutput,
weight: f32,
) -> AnimationOutputExpand description
Additively layer additive on top of base with weight.
pub fn add_output(
base: &AnimationOutput,
additive: &AnimationOutput,
weight: f32,
) -> AnimationOutputAdditively layer additive on top of base with weight.