pub enum LoadState {
NotLoaded,
Loading,
Loaded,
Failed(String),
}Expand description
The current load state of an asset identified by its raw ID.
Variants
NotLoaded
The asset has never been requested.
Loading
The asset is queued or currently being read from disk.
Loaded
The asset is available in the registry.
Failed(String)
Loading failed; the message describes the error.