pub struct AssetDependency {
pub depends_on: HashSet<u64>,
pub depended_by: HashSet<u64>,
}Expand description
Records which other assets a given asset depends on.
When an asset is reloaded all of its dependents are also re-queued so that stale composed assets (e.g. a material that references a texture) are always consistent.
Fields
depends_on: HashSet<u64>Raw IDs of the assets that this asset directly depends upon.
depended_by: HashSet<u64>Raw IDs of the assets that depend on this asset (reverse edges).
Implementations