pub struct FontMetrics {
pub cap_height: f32,
pub ascender: f32,
pub descender: f32,
pub line_gap: f32,
pub units_per_em: f32,
}Expand description
Metrics for the whole font face.
Fields
cap_height: f32Height of capital letters above the baseline, in font units.
ascender: f32Distance from baseline to top of tallest ascender.
descender: f32Distance from baseline to bottom of deepest descender (negative).
line_gap: f32Recommended line gap between successive text lines.
units_per_em: f32Units per em (coordinate space of the font).