pub struct WeakHandle<T: Asset> { /* private fields */ }Expand description
A weak handle that does not prevent the asset from being evicted.
Upgrade to an AssetHandle before accessing the data. If the upgrade
returns None the asset has been evicted and must be re-loaded.
Implementations