pub fn debug_log_blackboard(name: &str, key: &str) -> BehaviorNodeExpand description
A leaf that logs the current value of a blackboard key and succeeds.
pub fn debug_log_blackboard(name: &str, key: &str) -> BehaviorNodeA leaf that logs the current value of a blackboard key and succeeds.