pub fn set_blackboard<V>(name: &str, key: &str, value: V) -> BehaviorNodeExpand description
Instantly write a value onto the blackboard and succeed.
pub fn set_blackboard<V>(name: &str, key: &str, value: V) -> BehaviorNodeInstantly write a value onto the blackboard and succeed.