pub fn timeout_node(
name: &str,
timeout_secs: f32,
child: BehaviorNode,
) -> BehaviorNodeExpand description
Return Failure if child is still Running after timeout_secs seconds.
pub fn timeout_node(
name: &str,
timeout_secs: f32,
child: BehaviorNode,
) -> BehaviorNodeReturn Failure if child is still Running after timeout_secs seconds.