pub struct GoapPlanner;Expand description
Stateless A* GOAP planner.
Implementations
Sourceimpl GoapPlanner
impl GoapPlanner
Sourcepub fn plan(
start: &WorldState,
goal: &WorldState,
actions: &[Action],
max_depth: usize,
) -> Option<Vec<String>>
pub fn plan( start: &WorldState, goal: &WorldState, actions: &[Action], max_depth: usize, ) -> Option<Vec<String>>
Find the cheapest sequence of action names that transforms start into
a state satisfying goal, or None if no plan is reachable within
max_depth actions.
Sourcepub fn plan_with_cost(
start: &WorldState,
goal: &WorldState,
actions: &[Action],
max_depth: usize,
) -> Option<(Vec<String>, f32)>
pub fn plan_with_cost( start: &WorldState, goal: &WorldState, actions: &[Action], max_depth: usize, ) -> Option<(Vec<String>, f32)>
Plan and return full detail: path of action names + total estimated cost.
Sourcepub fn plan_alternatives(
start: &WorldState,
goal: &WorldState,
actions: &[Action],
max_depth: usize,
max_plans: usize,
) -> Vec<(Vec<String>, f32)>
pub fn plan_alternatives( start: &WorldState, goal: &WorldState, actions: &[Action], max_depth: usize, max_plans: usize, ) -> Vec<(Vec<String>, f32)>
Return all valid plans up to max_plans alternatives, sorted by cost.