pub fn parallel(
name: &str,
children: Vec<BehaviorNode>,
policy: ParallelPolicy,
) -> BehaviorNodeExpand description
Create a Parallel node from a list of children.
pub fn parallel(
name: &str,
children: Vec<BehaviorNode>,
policy: ParallelPolicy,
) -> BehaviorNodeCreate a Parallel node from a list of children.