pub fn sequence(name: &str, children: Vec<BehaviorNode>) -> BehaviorNodeExpand description
Create a Sequence node from a list of children.
pub fn sequence(name: &str, children: Vec<BehaviorNode>) -> BehaviorNodeCreate a Sequence node from a list of children.