pub enum BufferBarrierType {
ShaderStorage,
VertexAttrib,
IndirectDraw,
ShaderStorageAndVertex,
All,
}Expand description
Types of memory barriers that can be issued after compute writes.
Variants
ShaderStorage
Barrier for shader storage buffer reads/writes.
VertexAttrib
Barrier so that vertex attribute fetches see the writes.
IndirectDraw
Barrier so that indirect draw commands see the writes.
ShaderStorageAndVertex
Combined: shader storage + vertex attrib.
All
Combined: all three.
Implementations
Sourceimpl BufferBarrierType
impl BufferBarrierType
Sourcepub fn to_gl_bits(self) -> u32
pub fn to_gl_bits(self) -> u32
Convert to the raw GL bitfield.