BufferUsage

Enum BufferUsage 

pub enum BufferUsage {
    StaticDraw,
    DynamicDraw,
    StreamDraw,
    StreamRead,
    DynamicCopy,
}
Intended usage hint when creating a buffer.

Variants



StaticDraw

Data is set once and used many times (GL_STATIC_DRAW equivalent).



DynamicDraw

Data changes frequently and is used many times (GL_DYNAMIC_DRAW equivalent).



StreamDraw

Data changes every frame (GL_STREAM_DRAW equivalent).



StreamRead

GPU writes, CPU reads (GL_STREAM_READ equivalent).



DynamicCopy

GPU writes, GPU reads (GL_DYNAMIC_COPY equivalent).

Implementations

Source

impl BufferUsage

pub fn to_gl(self) -> u32

Map to a GL enum value (integer form used by glow).