pub struct ComputeDispatch { /* private fields */ }Expand description
Executes compute shader dispatches.
Implementations
Sourceimpl ComputeDispatch
impl ComputeDispatch
Sourcepub fn set_auto_barrier(&mut self, enabled: bool)
pub fn set_auto_barrier(&mut self, enabled: bool)
Set whether barriers are automatically issued after dispatch.
Sourcepub fn set_default_barrier(&mut self, bits: u32)
pub fn set_default_barrier(&mut self, bits: u32)
Set the default barrier bits.
Sourcepub fn dispatch(
&self,
gl: &Context,
program: &ComputeProgram,
dim: DispatchDimension,
)
pub fn dispatch( &self, gl: &Context, program: &ComputeProgram, dim: DispatchDimension, )
Dispatch a compute shader with the given program and dimensions.
Sourcepub fn dispatch_1d(
&self,
gl: &Context,
program: &ComputeProgram,
total_elements: u32,
local_size_x: u32,
)
pub fn dispatch_1d( &self, gl: &Context, program: &ComputeProgram, total_elements: u32, local_size_x: u32, )
Dispatch 1D: convenience for dispatching over N elements.
Sourcepub fn dispatch_2d(
&self,
gl: &Context,
program: &ComputeProgram,
width: u32,
height: u32,
local_size: WorkgroupSize,
)
pub fn dispatch_2d( &self, gl: &Context, program: &ComputeProgram, width: u32, height: u32, local_size: WorkgroupSize, )
Dispatch 2D: convenience for dispatching over a width x height grid.
Sourcepub fn dispatch_3d(
&self,
gl: &Context,
program: &ComputeProgram,
w: u32,
h: u32,
d: u32,
local_size: WorkgroupSize,
)
pub fn dispatch_3d( &self, gl: &Context, program: &ComputeProgram, w: u32, h: u32, d: u32, local_size: WorkgroupSize, )
Dispatch 3D.
Sourcepub fn dispatch_indirect(
&self,
gl: &Context,
program: &ComputeProgram,
buffer: BufferHandle,
offset: usize,
)
pub fn dispatch_indirect( &self, gl: &Context, program: &ComputeProgram, buffer: BufferHandle, offset: usize, )
Indirect dispatch: read dispatch arguments from a buffer on the GPU.
Sourcepub fn dispatch_with_barrier(
&self,
gl: &Context,
program: &ComputeProgram,
dim: DispatchDimension,
barrier: BufferBarrierType,
)
pub fn dispatch_with_barrier( &self, gl: &Context, program: &ComputeProgram, dim: DispatchDimension, barrier: BufferBarrierType, )
Dispatch with an explicit barrier type (overrides auto).
Sourcepub fn dispatch_multi(
&self,
gl: &Context,
program: &ComputeProgram,
dims: &[DispatchDimension],
)
pub fn dispatch_multi( &self, gl: &Context, program: &ComputeProgram, dims: &[DispatchDimension], )
Dispatch multiple passes of the same program with different dimensions.