pub struct KernelLibrary { /* private fields */ }Expand description
Library of all built-in compute kernels, providing easy access to sources and parameter setup.
Implementations
Sourceimpl KernelLibrary
impl KernelLibrary
Sourcepub fn source(&self, id: KernelId) -> Option<&'static str>
pub fn source(&self, id: KernelId) -> Option<&'static str>
Get the raw GLSL source for a kernel.
Sourcepub fn shader_source(&self, id: KernelId) -> Option<ShaderSource>
pub fn shader_source(&self, id: KernelId) -> Option<ShaderSource>
Build a ShaderSource for a kernel, with version header and optional defines.
Sourcepub fn compile(
&self,
gl: &Context,
id: KernelId,
) -> Result<ComputeProgram, String>
pub fn compile( &self, gl: &Context, id: KernelId, ) -> Result<ComputeProgram, String>
Compile a kernel into a ComputeProgram.
Sourcepub fn compile_with_defines(
&self,
gl: &Context,
id: KernelId,
defines: &[(&str, &str)],
) -> Result<ComputeProgram, String>
pub fn compile_with_defines( &self, gl: &Context, id: KernelId, defines: &[(&str, &str)], ) -> Result<ComputeProgram, String>
Compile a kernel with extra defines.
Sourcepub fn available_kernels(&self) -> Vec<KernelId>
pub fn available_kernels(&self) -> Vec<KernelId>
List all available kernel IDs.