pub struct CraftingQueue { /* private fields */ }Expand description
Ordered pending job queue with a maximum of 8 slots.
Implementations
Sourceimpl CraftingQueue
impl CraftingQueue
pub fn new() -> Self
Sourcepub fn has_capacity(&self) -> bool
pub fn has_capacity(&self) -> bool
Whether the queue has room for another job.
pub fn is_empty(&self) -> bool
Sourcepub fn enqueue(
&mut self,
recipe_id: impl Into<String>,
ingredients_consumed: Vec<(String, u32)>,
started_at: f32,
duration: f32,
quantity: u32,
owner_id: impl Into<String>,
) -> Option<u64>
pub fn enqueue( &mut self, recipe_id: impl Into<String>, ingredients_consumed: Vec<(String, u32)>, started_at: f32, duration: f32, quantity: u32, owner_id: impl Into<String>, ) -> Option<u64>
Enqueue a new job, returning its id or None if the queue is full.
Sourcepub fn front(&self) -> Option<&CraftingJob>
pub fn front(&self) -> Option<&CraftingJob>
Peek at the front job without removing it.
Sourcepub fn dequeue(&mut self) -> Option<CraftingJob>
pub fn dequeue(&mut self) -> Option<CraftingJob>
Dequeue the front job.
Sourcepub fn cancel(&mut self, job_id: u64) -> Option<CraftingJob>
pub fn cancel(&mut self, job_id: u64) -> Option<CraftingJob>
Remove a job by id (e.g. on cancellation).
Sourcepub fn all_jobs(&self) -> &[CraftingJob]
pub fn all_jobs(&self) -> &[CraftingJob]
All jobs currently in the queue.