pub struct CommandRegistry { /* private fields */ }Expand description
A simple in-game console command registry.
Commands are registered with a name, description, and a handler function
that accepts Vec<String> args and returns a String result (or an error
string).
Implementations
Sourceimpl CommandRegistry
impl CommandRegistry
pub fn new() -> Self
Sourcepub fn register(
&mut self,
name: impl Into<String>,
description: impl Into<String>,
handler: Box<dyn Fn(Vec<String>) -> String + Send + Sync>,
)
pub fn register( &mut self, name: impl Into<String>, description: impl Into<String>, handler: Box<dyn Fn(Vec<String>) -> String + Send + Sync>, )
Register a command with a name, description, and handler.
Sourcepub fn add_alias(&mut self, name: &str, alias: impl Into<String>)
pub fn add_alias(&mut self, name: &str, alias: impl Into<String>)
Add an alias for an existing command.
Sourcepub fn unregister(&mut self, name: &str)
pub fn unregister(&mut self, name: &str)
Unregister a command by name.
Sourcepub fn execute(&self, input: &str) -> Result<String, String>
pub fn execute(&self, input: &str) -> Result<String, String>
Execute a raw input string. Parses the first token as the command name and the remainder as space-separated arguments.
Sourcepub fn completions(&self, prefix: &str) -> Vec<String>
pub fn completions(&self, prefix: &str) -> Vec<String>
Return all command names that start with prefix, sorted.
pub fn is_empty(&self) -> bool