pub struct InspectorWatcher {
pub object_name: String,
/* private fields */
}Expand description
Stores last-seen field values for a registered object and detects changes.
Fields
object_name: StringImplementations
Sourceimpl InspectorWatcher
impl InspectorWatcher
pub fn new(object_name: impl Into<String>) -> Self
Sourcepub fn check_changes(
&mut self,
current_fields: &[InspectorField],
) -> Vec<(String, InspectorValue, InspectorValue)>
pub fn check_changes( &mut self, current_fields: &[InspectorField], ) -> Vec<(String, InspectorValue, InspectorValue)>
Update the watcher with the current fields and return a list of
(field_name, old_value, new_value) tuples for any changed fields.
Sourcepub fn reset(&mut self, fields: &[InspectorField])
pub fn reset(&mut self, fields: &[InspectorField])
Force-record all current fields without reporting changes.
pub fn field_count(&self) -> usize