pub trait Inspectable {
// Required methods
fn inspect(&self) -> Vec<InspectorField>;
fn apply_changes(&mut self, changes: Vec<(String, InspectorValue)>);
}Expand description
Objects that can expose their fields to the runtime inspector.
Required Methods
Sourcefn inspect(&self) -> Vec<InspectorField>
fn inspect(&self) -> Vec<InspectorField>
Return a list of inspector fields describing this object’s current state.
Sourcefn apply_changes(&mut self, changes: Vec<(String, InspectorValue)>)
fn apply_changes(&mut self, changes: Vec<(String, InspectorValue)>)
Apply a list of (name, new_value) changes from the inspector.