pub struct MetricsRegistry { /* private fields */ }Expand description
Thread-safe registry for creating and updating metrics.
All operations are guarded by an internal Mutex, making the registry safe
to share across threads via Arc<MetricsRegistry>.
Implementations
Sourceimpl MetricsRegistry
impl MetricsRegistry
Create a registry wrapped in an Arc for sharing.
Sourcepub fn counter(&self, name: &str, labels: HashMap<String, String>) -> i64
pub fn counter(&self, name: &str, labels: HashMap<String, String>) -> i64
Increment a counter by delta (default 1).
Sourcepub fn counter_by(
&self,
name: &str,
labels: HashMap<String, String>,
delta: i64,
) -> i64
pub fn counter_by( &self, name: &str, labels: HashMap<String, String>, delta: i64, ) -> i64
Increment a counter by a specific amount.
Sourcepub fn gauge(&self, name: &str, labels: HashMap<String, String>, value: f64)
pub fn gauge(&self, name: &str, labels: HashMap<String, String>, value: f64)
Set a gauge to value.
Sourcepub fn gauge_add(&self, name: &str, labels: HashMap<String, String>, delta: f64)
pub fn gauge_add(&self, name: &str, labels: HashMap<String, String>, delta: f64)
Add delta to a gauge.
Sourcepub fn histogram_observe(
&self,
name: &str,
labels: HashMap<String, String>,
value: f64,
)
pub fn histogram_observe( &self, name: &str, labels: HashMap<String, String>, value: f64, )
Record a histogram observation.
Sourcepub fn set_default_buckets(&self, boundaries: Vec<f64>)
pub fn set_default_buckets(&self, boundaries: Vec<f64>)
Override the default bucket boundaries for future histogram metrics.
Sourcepub fn get_counter(&self, name: &str, labels: &HashMap<String, String>) -> i64
pub fn get_counter(&self, name: &str, labels: &HashMap<String, String>) -> i64
Get the current counter value (returns 0 if not found).