DeferredPipeline

Struct DeferredPipeline 

pub struct DeferredPipeline {
Show 16 fields pub gbuffer: GBuffer, pub hdr_framebuffer: HdrFramebuffer, pub depth_prepass: DepthPrePass, pub geometry_pass: GeometryPass, pub lighting_pass: LightingPass, pub forward_pass: ForwardPass, pub postprocess_pass: PostProcessPass, pub render_queue: RenderQueue, pub viewport: Viewport, pub view_matrix: Mat4, pub projection_matrix: Mat4, pub camera_position: [f32; 3], pub frame_stats: DeferredFrameStats, pub initialized: bool, pub frame_number: u64, pub dt: f32,
}
The complete deferred rendering pipeline, orchestrating all passes.

Fields

gbuffer: GBuffer

The G-Buffer.

hdr_framebuffer: HdrFramebuffer

HDR framebuffer.

depth_prepass: DepthPrePass

Depth pre-pass.

geometry_pass: GeometryPass

Geometry pass.

lighting_pass: LightingPass

Lighting pass.

forward_pass: ForwardPass

Forward pass.

postprocess_pass: PostProcessPass

Post-processing pass.

render_queue: RenderQueue

Render queue.

viewport: Viewport

Current viewport.

view_matrix: Mat4

View matrix.

projection_matrix: Mat4

Projection matrix.

camera_position: [f32; 3]

Camera position.

frame_stats: DeferredFrameStats

Frame statistics.

initialized: bool

Whether the pipeline has been initialized.

frame_number: u64

Frame counter.

dt: f32

Delta time for the current frame.

Implementations

Source

impl DeferredPipeline

pub fn new(width: u32, height: u32) -> Self

Create a new deferred pipeline with the given viewport dimensions.

pub fn initialize(&mut self) -> Result<(), String>

Initialize all GPU resources.

pub fn shutdown(&mut self)

Shut down and release all resources.

pub fn resize(&mut self, width: u32, height: u32)

Resize the pipeline to new viewport dimensions.

pub fn set_camera( &mut self, position: [f32; 3], view: Mat4, projection: Mat4, frustum_planes: [[f32; 4]; 6], )

Set the camera for this frame.

pub fn submit(&mut self, item: RenderItem)

Submit a render item.

pub fn execute_frame(&mut self, dt: f32)

Execute the full deferred rendering pipeline for one frame.

pub fn stats_summary(&self) -> String

Get a summary string of the current frame stats.