pub struct ConsoleSink {
pub pending: Mutex<Vec<(LogLevel, String)>>,
}Expand description
A sink that can receive log records from the log crate.
Callers hold a reference and push into the DevConsole.
Fields
pending: Mutex<Vec<(LogLevel, String)>>Lines captured from log macros, drained periodically into DevConsole.
Implementations