pub struct VectorFieldGizmo {
pub grid_origin: Vec3,
pub grid_size: Vec3,
pub cell_count: [u32; 3],
pub arrow_scale: f32,
pub color_min: Vec4,
pub color_max: Vec4,
pub max_magnitude: f32,
pub visible: bool,
}Expand description
Samples a force field and draws vectors as arrows.
Fields
grid_origin: Vec3grid_size: Vec3cell_count: [u32; 3]arrow_scale: f32color_min: Vec4color_max: Vec4max_magnitude: f32visible: boolImplementations
Sourceimpl VectorFieldGizmo
impl VectorFieldGizmo
pub fn new(origin: Vec3, size: Vec3, cells: [u32; 3]) -> Self
Sourcepub fn sample_positions(&self) -> Vec<Vec3>
pub fn sample_positions(&self) -> Vec<Vec3>
Sample positions for the vector field grid.
Sourcepub fn make_arrow(&self, pos: Vec3, vector: Vec3) -> (Vec3, Vec3, Vec4)
pub fn make_arrow(&self, pos: Vec3, vector: Vec3) -> (Vec3, Vec3, Vec4)
Given a vector value at a position, produce an arrow (start, end, color).
Sourcepub fn arrows_for_samples(
&self,
samples: &[(Vec3, Vec3)],
) -> Vec<(Vec3, Vec3, Vec4)>
pub fn arrows_for_samples( &self, samples: &[(Vec3, Vec3)], ) -> Vec<(Vec3, Vec3, Vec4)>
Generate arrows for a set of (position, vector) samples.
Sourcepub fn color_for_magnitude(&self, magnitude: f32) -> Vec4
pub fn color_for_magnitude(&self, magnitude: f32) -> Vec4
Color interpolated by magnitude.