ItemCategory

Enum ItemCategory 

pub enum ItemCategory {
Show 53 variants Sword, Greatsword, Dagger, Axe, Greataxe, Mace, Hammer, Spear, Polearm, Whip, Bow, Crossbow, Thrown, Gun, Rifle, Staff, Wand, Orb, Tome, Shield, Buckler, TowerShield, Helmet, Hood, Crown, Chestplate, Robe, Leather, Greaves, Leggings, Pants, Gauntlets, Gloves, Boots, Sabatons, Ring, Amulet, Belt, Cloak, Potion, Food, Scroll, Bomb, Ore, Gem, Herb, Hide, Wood, Cloth, QuestItem, Key, Currency, Junk,
}

Variants



Sword



Greatsword



Dagger



Axe



Greataxe



Mace



Hammer



Spear



Polearm



Whip



Bow



Crossbow



Thrown



Gun



Rifle



Staff



Wand



Orb



Tome



Shield



Buckler



TowerShield



Helmet



Hood



Crown



Chestplate



Robe



Leather



Greaves



Leggings



Pants



Gauntlets



Gloves



Boots



Sabatons



Ring



Amulet



Belt



Cloak



Potion



Food



Scroll



Bomb



Ore



Gem



Herb



Hide



Wood



Cloth



QuestItem



Key



Currency



Junk

Implementations

Source

impl ItemCategory

pub fn display_name(&self) -> &'static str

pub fn is_weapon(&self) -> bool

pub fn is_armor(&self) -> bool

pub fn is_accessory(&self) -> bool

pub fn is_consumable(&self) -> bool

pub fn is_material(&self) -> bool

pub fn default_stack_size(&self) -> u32

pub fn two_handed(&self) -> bool