Module loot_editor

Module loot_editor 

Structs

AchievementTracker
ActiveBuffs
AffinityBonus
AffinityRegistry
AffixRegistry
AliasTable
BalanceEstimate
BossKillModifier
CdfCurve
ChestOpenResult
ChiSquaredResult
CollectionAchievement
ComprehensiveLootEditor
CraftingIngredient
CraftingRecipe
CraftingSystem
CraftingSystemEx
Currency
CurrencyStack
CurrencyWallet
DifficultyScaler
DropContext
DropRateAnalysisReport
DropRateAnalyzer
DropResult
DropSource
DropSourceRegistry
DropStreakTracker
DungeonAnalysis
DungeonLootResult
DungeonRoom
DungeonRun
DungeonSimulator
DurabilityTracker
EconomySimParams
EconomySimSnapshot
EconomySimulator
EconomySnapshot
EconomyTracker
Enchantment
EnchantmentLibrary
EnchantmentSystem
EntryAnalysis
EventManager
ExtendedLootEditor
FilterRule
FullLootSimulation
GemCombination
GemCombinationRegistry
GemDefinition
GeneratedItem
GlobalLootEditorState
HistogramBin
IdentificationService
InflationSimulator
Inventory
InventorySlot
InventorySystem
Item
ItemAffinity
ItemAffix
ItemAffixRoll
ItemComparator
ItemCraftingRecipe
ItemDropSimulation
ItemDurability
ItemDurabilityEx
ItemEffect
ItemEnchantment
ItemFrequencyData
ItemGenerator
ItemProgression
ItemRating
ItemRatingDatabase
ItemScore
ItemScoreCache
ItemSet
ItemSetBonus
ItemSetDef
ItemStats
ItemTagDefinition
ItemTrade
ItemVisual
ItemVisualRegistry
LootAccumulation
LootAchievement
LootAchievementTracker
LootAnalyticsEvent
LootAnalyticsPipeline
LootBalanceReport
LootBalanceTool
LootBudget
LootChest
LootContext
LootCooldown
LootCooldownTracker
LootDebugger
LootDropRule
LootEditor
LootEntryViz
LootEvent
LootEventSchedule
LootExportConfig
LootFilter
LootFilterEx
LootFilterExt
LootFilterRule
LootGraph
LootGraphNode
LootHistory
LootHistoryEntry
LootImportResult
LootMilestone
LootMultiplier
LootNotification
LootNotificationQueue
LootPipeline
LootPitySystem
LootPreviewCache
LootRng
LootRoller
LootRuleEngine
LootScenario
LootScenarioRunner
LootSearchQuery
LootSimulationReport
Full loot simulation report
LootStatistics
LootStreak
LootSystemHealth
LootTable
LootTableAnalyzer
LootTableBuilder
LootTableEntry
LootTableGenerator
LootTableHierarchy
LootTableVisualizationData
LootTier
LootTierList
LoreDatabase
LoreEntry
MagicFindModifier
MarketListing
MarketTransaction
Marketplace
MasterLootEditor
MerchantInventory
MilestoneTracker
MonteCarloResult
MultiTierPity
NpcLootProfile
NpcLootRegistry
PitySystem
PityTier
PityTracker
PlayerEconomy
PlayerWallet
PrestigeReward
PrestigeRewardEx
PrestigeSystem
PrestigeSystemEx
QuestLootManager
QuestRewardPool
RandomEncounter
RandomEncounterTable
RewardTier
RewardTierTable
RotatingLootShop
SalvageResult
SalvageResultEx
SalvageSystem
SalvageSystemEx
SalvageTable
ScrollOfIdentify
SeasonalLootManager
SeasonalLootSet
SessionStats
SetBonus
SetBonusRegistry
SetDatabase
SetItemBonus
SetTracker
ShopItem
Socket
SocketSystem
TagRegistry
TradeHistory
TransmutationRecipe
TransmutationRecipeEx
TransmutationSystem
TransmutationSystemEx
TreasureChestSystem
UnidentifiedItem
UnidentifiedItemEx
UpgradeNode
UpgradePath
VendorItem
VendorManager
VendorNpc
VendorPricer
WeightedEntry
WeightedLootPool
WorldDropManager
WorldEvent
ZoneDifficultyModifier
ZoneLootConfig
ZoneLootRegistry

Enums

AffixType
ChestKind
ChestType
CraftResult
CraftingStation
CurrencyKind
DropCondition
DungeonRoomType
EffectTrigger
EnchantmentEffect
EnchantmentTarget
EventType
FilterAction
FilterActionExt
FilterCondition
IdentifyResult
ItemQuality
ItemRarity
ItemType
LootEntryKind
RollCountMode
Season
SocketColor
VendorType

Constants

LOOT_AFFIX_MAX_PER_ITEM
LOOT_AFFIX_PERFECT_THRESHOLD
LOOT_AFFIX_PREFIX_MAX
LOOT_AFFIX_SUFFIX_MAX
LOOT_AFFIX_TIER_MAX
LOOT_ANALYTICS_MAX_EVENTS
LOOT_ANALYTICS_PIPELINE_DEFAULT_SIZE
LOOT_CHEST_MAX_CONTENTS
LOOT_CHEST_RESPAWN_MIN_SECS
LOOT_COMPARATOR_STAT_MAX
LOOT_CURRENCY_TYPE_MAX
LOOT_DEFAULT_LUCK
LOOT_DURABILITY_DAMAGE_ON_DEATH
LOOT_DURABILITY_MAX
LOOT_ECONOMY_SNAPSHOT_INTERVAL
LOOT_ENCHANT_TIER_MAX
LOOT_GEM_COMBINE_MAX_INGREDIENTS
LOOT_HEALTH_CHECK_INTERVAL_SECS
LOOT_HISTORY_MAX
LOOT_IDENTIFICATION_SCROLL_ID
LOOT_INVENTORY_DEFAULT_CAPACITY
LOOT_INVENTORY_DEFAULT_SLOTS
LOOT_INVENTORY_MAX_CAPACITY
LOOT_ITEM_GLOW_INTENSITY_MAX
LOOT_MAX_MAGIC_FIND
LOOT_MAX_STACK
LOOT_MAX_TABLE_ENTRIES
LOOT_MAX_TOTAL_ITEMS
LOOT_MERCHANT_MAX_ITEMS
LOOT_MERCHANT_MAX_MARKUP
LOOT_MERCHANT_MIN_MARKUP
LOOT_MERCHANT_RESTOCK_DEFAULT_SECS
LOOT_MILESTONE_ANNOUNCE_DELAY_SECS
LOOT_MILESTONE_MAX
LOOT_NOTIFICATION_ICON_SIZE
LOOT_NOTIFICATION_TTL_SECS
LOOT_NPC_MAX_POOLS
LOOT_PITY_BASE_THRESHOLD
LOOT_POOL_MAX_ENTRIES
LOOT_PRESTIGE_MAX_LEVEL
LOOT_QUEST_MAX_CHOICES
LOOT_ROTATING_SHOP_SLOTS
LOOT_SALVAGE_ESSENCE_MAX
LOOT_SALVAGE_GOLD_RATE_DEFAULT
LOOT_SCENARIO_MAX
LOOT_SEARCH_PAGE_SIZE_DEFAULT
LOOT_SEARCH_PAGE_SIZE_MAX
LOOT_SEASONAL_EVENT_MAX
LOOT_SEASON_COUNT
LOOT_SET_MAX_PIECES
LOOT_SHOP_MAX_ITEMS
LOOT_SIMULATION_DEFAULT_ITERATIONS
LOOT_SOURCE_MAX
LOOT_STREAK_DECAY_THRESHOLD_SECS
LOOT_STREAK_MAX_LEVEL
LOOT_SYSTEM_VERSION
LOOT_TAG_MAX
LOOT_TRADE_HISTORY_MAX
LOOT_TRANSFER_COOLDOWN_SECS
LOOT_TRANSMUTATION_HISTORY_MAX
LOOT_UNIDENTIFIED_SLOT_MAX
LOOT_VISUAL_REGISTRY_MAX
LOOT_WALLET_GOLD_CAP
LOOT_WEIGHT_PRECISION
LOOT_ZONE_MAX

Traits

LootModifier

Functions

allocate_budget
base_drop_chance
batch_simulate
Batch simulate multiple tables and compare
binomial_coef
Binomial coefficient C(n, k)
binomial_pmf
Binomial probability P(X = k) for n trials with success rate p
build_default_milestones
build_default_tag_registry
build_dragon_boss_loot_table
build_extended_item_catalog
build_gacha_pity
build_goblin_loot_table
build_item_catalog
build_standard_item_effects
build_treasure_chest_table
build_visualization
build_weapon_upgrade_path
chi_squared_test
Chi-squared goodness-of-fit test
clamp_item_level
components_to_gold
compute_histogram
compute_item_cdf
Compute cumulative distribution function for item drop probabilities
compute_item_frequencies
create_full_loot_editor
default_loot_filter
describe_rarity
drop_rate_summary
Print-ready summary of drop rates for a table
estimate_drop_rate_mle
Compute drop rate from observed data using MLE
expected_drops
Expected number of drops for n kills with rate p
expected_runs_for_set
Advanced: Compute expected number of runs to complete a set
expected_streak_length
Expected streak length before success
format_drops
format_gold
format_item_tooltip
generate_report
geometric_expected
Expected number of trials until first success
geometric_pmf
Geometric distribution: probability of first success at trial k
gini_coefficient
Compute the Gini coefficient of item value distribution (inequality measure)
gold_to_components
import_table_from_description
Import loot table from simple text description
is_loot_system_ready
is_table_fair
Detect if a loot table is “fair” (chi-squared p-value > 0.05 means no significant deviation)
item_level_bracket
item_level_to_power
item_sell_value
item_slot_name
kills_for_50_pct
kills_for_90_pct
kills_for_99_pct
kills_for_probability
Compute how many kills needed for 50% / 90% / 99% chance of getting item
loot_analytics_summary
loot_economy_info
loot_editor_full_version
loot_editor_info
loot_editor_version
loot_full_system_summary
loot_max_item_id
loot_module_list
loot_pipeline_steps
loot_seed_from_entity
loot_subsystem_count
loot_system_health_check
loot_system_version
loot_version_string
luck_for_n_kills
Estimate luck coefficient needed to get item in N kills
max_affix_count
max_zone_ilvl
negative_binomial_pmf
Negative binomial: P(r-th success on n-th trial)
normalize_weights
Weight normalization (so weights sum to 1.0)
normalize_weights_inplace
pick_weighted_index
poisson_pmf
power_to_item_level
prob_at_least_one
Probability of getting at least one drop in n kills
rarity_color_hex
rarity_drop_weight
rarity_value_multiplier
recommended_zone_ilvl
roll_rarity
run_additional_loot_tests
run_all_loot_editor_tests
run_all_loot_tests
run_comprehensive_loot_tests
run_final_loot_integration
run_loot_system_tests
run_loot_tests
Run complete test suite for loot system
run_monte_carlo
run_vendor_tests
sample_item_by_rarity
Sample items weighted by rarity probability (given zone difficulty)
sample_roll_count
Sample count from RollCountMode
sample_without_replacement
Sample from distribution without replacement (for guaranteed drops)
search_catalog
Catalog search with multiple criteria
simulate_budget_utilization
streak_probability
table_to_item_weights
Convert loot table to weighted item list
total_loot_modules
validate_loot_system
weighted_roll
wilson_confidence_interval
Wilson score interval for drop rate confidence