MaterialEditorState

Struct MaterialEditorState 

pub struct MaterialEditorState {
Show 16 fields pub library: MaterialLibrary, pub selected_material: Option<u64>, pub active_tab: MaterialEditorTab, pub preview_shape: PreviewShape, pub preview_lighting: PreviewLighting, pub preview_rotate: bool, pub preview_rotation: f32, pub preview_zoom: f32, pub show_wireframe: bool, pub show_uv_grid: bool, pub show_tangent_space: bool, pub search_query: String, pub category_filter: Option<String>, pub history: Vec<Material>, pub history_pos: usize, pub compare_material: Option<u64>,
}

Fields

library: MaterialLibraryselected_material: Option<u64>active_tab: MaterialEditorTabpreview_shape: PreviewShapepreview_lighting: PreviewLightingpreview_rotate: boolpreview_rotation: f32preview_zoom: f32show_wireframe: boolshow_uv_grid: boolshow_tangent_space: boolsearch_query: Stringcategory_filter: Option<String>history: Vec<Material>history_pos: usizecompare_material: Option<u64>

Implementations

Source

impl MaterialEditorState

pub fn new() -> Self

pub fn selected_material(&self) -> Option<&Material>

pub fn selected_material_mut(&mut self) -> Option<&mut Material>

pub fn snapshot(&mut self)

pub fn undo(&mut self)

Undo to the last snapshot. snapshot() is called before an edit, so the state to return to is the newest snapshot; the old code skipped it and went one further back (and did nothing with one snapshot). The current state is kept so redo can return to it.

pub fn redo(&mut self)

pub fn update(&mut self, dt: f32)

pub fn search_results(&self) -> Vec<&Material>

pub fn duplicate_selected(&mut self) -> Option<u64>

pub fn create_variant(&mut self) -> Option<u64>