Module modeling_editor

Module modeling_editor 

Structs

Aabb3
AdvancedSculpt
BatchProcessor
BranchingHistory
BrushParams
BrushPreset
BrushPresetLibrary
CatmullRomSpline
ColorGradient
ConstraintSolver
CurveLibrary
DecalLayer
GradientStop
GridHelper
GroupInfo
GroupManager
HistoryNode
KdNode
KdTree
LatticeDeformer
LodLevel
LodStreamer
MaterialLibrary
ModelAnimation
ModelClipboard
ModelCurve
ModelEditor
ModelIO
ModelKeyframe
ModelLayer
ModelParticle
ModelQuality
ModelRenderData
Holds the data needed to render the model in the ASCII engine.
ModelSerializer
ModelSnapshot
ModelingToolContext
ModelingToolContext2
NoiseGenerator
Octree
OctreeNode
PaletteManager
ParticleBone
ParticleConstraint
ParticleCsg
ParticleDecal
ParticleDelta
ParticleDiff
ParticleEffects
ParticleField
ParticleMaterial
ParticleMesh
ParticleModel
ParticlePicker
ParticleRenderer
ParticleScatter
ParticleSkeleton
ParticleStats
PhysicsParticle
PhysicsSimulator
PrimitiveBuilder
ProceduralPatterns
Ray3
Remesher
RenderBuffer
RenderCamera
RenderCell
ScatterInstance
ScatterSettings
SculptEngine
SculptMask
SelectionSystem
SpringConstraint
Stencil
TextureProjector
TransformTools
UndoStack
VisualizationHelper

Enums

BrushKind
ConstraintKind
CsgOperation
CurveType
DecalBlend
EasingType
FalloffCurve
FieldType
LayerBlendMode
MaterialType
ProjectionMode
SymmetryMode

Constants

DEFAULT_BRUSH_DENSITY
DEFAULT_BRUSH_RADIUS
DEFAULT_BRUSH_STRENGTH
EPSILON
GOLDEN_RATIO
INV_GOLDEN_RATIO
MARCHING_CUBES_THRESHOLD
MAX_BONE_INFLUENCES
MAX_LOD_LEVELS
MAX_UNDO_STEPS
METABALL_THRESHOLD
PHI
PI
SQRT3
TAU

Functions

angle_between
Angle between two vectors in radians.
asymmetric_smoothstep
Smootherstep variant with asymmetric rise/fall
barycentric
Barycentric coordinates of point P in triangle ABC.
bounding_sphere
clamp_vec3
Clamp a Vec3 component-wise to given bounds.
closest_point_on_segment
Closest point on segment AB to point P.
compute_view_dependent_glyph
For each particle, determine the best ASCII glyph for a given view direction.
decompose_mat4
depth_to_ascii
Convert a depth value to ASCII shading character.
euler_to_quat
halton
Halton sequence for quasi-random sampling
hilbert_d2xy
Map a 1D index to a 2D Hilbert curve coordinate (order n)
hsl_to_rgb
Convert HSL to RGB
hsv_to_rgb
hue_distance
lcg_rand
Random float in [0,1] from a LCG seed (mutates seed)
lerp_color_hsv
Linear interpolation between two colors in HSV space.
mesh_surface_area_2
point_in_polygon_xz
project_onto_plane
Project a vector onto a plane defined by its normal.
project_onto_plane_normalized
Project vector onto a plane and normalize
project_to_screen
Project a Vec3 world position to screen space (Vec2) given MVP matrix.
quat_to_euler
reflect_vector
Reflect vector across a normal
remap
Remap a value from [in_min, in_max] to [out_min, out_max].
remap_clamped
Remap clamped — like remap but clamps output
rgb_to_hsl
Convert RGB to HSL
rgb_to_hsv
rotate_around_axis
Rotate a Vec3 by angle around an axis
sdf_aabb
Signed distance from point to AABB.
sdf_cylinder
Signed distance from point to cylinder.
sdf_sphere
Signed distance from point to sphere.
sdf_torus
Signed distance from point to torus.
signed_angle
Signed angle from a to b around axis.
signed_angle_deg
Signed angle between two Vec3s around an axis (degrees)
simple_noise_2d
smootherstep
smoothstep
smoothstep_exp
Smoothstep with custom exponent
sort_particles_back_to_front
Sort particles back-to-front for correct alpha blending.
sort_particles_front_to_back
Sort particles front-to-back for depth testing.
triangle_area
unproject_ray
Unproject screen position to a world-space Ray3.