pub struct ParticleCsg;Implementations
Sourceimpl ParticleCsg
impl ParticleCsg
Sourcepub fn union(
a: &ParticleModel,
b: &ParticleModel,
merge_threshold: f32,
) -> ParticleModel
pub fn union( a: &ParticleModel, b: &ParticleModel, merge_threshold: f32, ) -> ParticleModel
Union: merge two models, removing overlapping particles
Sourcepub fn subtract(
a: &ParticleModel,
b: &ParticleModel,
margin: f32,
) -> ParticleModel
pub fn subtract( a: &ParticleModel, b: &ParticleModel, margin: f32, ) -> ParticleModel
Subtract: keep particles from A that are not inside B’s bounding volume
Sourcepub fn intersect(
a: &ParticleModel,
b: &ParticleModel,
margin: f32,
) -> ParticleModel
pub fn intersect( a: &ParticleModel, b: &ParticleModel, margin: f32, ) -> ParticleModel
Intersect: keep only particles from A that overlap with B’s volume
Sourcepub fn shell(
model: &ParticleModel,
b: &ParticleModel,
shell_thickness: f32,
) -> ParticleModel
pub fn shell( model: &ParticleModel, b: &ParticleModel, shell_thickness: f32, ) -> ParticleModel
Shell: keep particles near the surface of B (within threshold)
Sourcepub fn apply(
op: &CsgOperation,
a: &ParticleModel,
b: &ParticleModel,
threshold: f32,
) -> ParticleModel
pub fn apply( op: &CsgOperation, a: &ParticleModel, b: &ParticleModel, threshold: f32, ) -> ParticleModel
Apply operation