pub struct ParticlePicker;Implementations
Sourceimpl ParticlePicker
impl ParticlePicker
Sourcepub fn pick_closest(
particles: &[ModelParticle],
ray: &Ray3,
tolerance: f32,
) -> Option<(usize, f32)>
pub fn pick_closest( particles: &[ModelParticle], ray: &Ray3, tolerance: f32, ) -> Option<(usize, f32)>
Find the closest particle to a camera ray within a tolerance cylinder. Returns (particle_index, t_along_ray) or None.
Sourcepub fn pick_all_in_ray(
particles: &[ModelParticle],
ray: &Ray3,
tolerance: f32,
) -> Vec<usize>
pub fn pick_all_in_ray( particles: &[ModelParticle], ray: &Ray3, tolerance: f32, ) -> Vec<usize>
Find all particles within a tolerance cylinder of the ray.
Sourcepub fn pick_ray_sphere(
particles: &[ModelParticle],
ray: &Ray3,
particle_radius: f32,
) -> Option<(usize, f32)>
pub fn pick_ray_sphere( particles: &[ModelParticle], ray: &Ray3, particle_radius: f32, ) -> Option<(usize, f32)>
Ray-sphere intersection per particle for exact picking.