pub struct RagdollEditor {
pub bones: HashMap<String, RagdollBone>,
pub joints: Vec<RagdollJoint>,
pub blend_mode: RagdollBlendMode,
pub animation_blend: f32,
pub blend_time: f32,
pub current_blend_timer: f32,
pub active: bool,
pub total_mass: f32,
pub com_world: Vec3,
pub next_body_id: u64,
}Fields
bones: HashMap<String, RagdollBone>joints: Vec<RagdollJoint>blend_mode: RagdollBlendModeanimation_blend: f32blend_time: f32current_blend_timer: f32active: booltotal_mass: f32com_world: Vec3next_body_id: u64Implementations
Sourceimpl RagdollEditor
impl RagdollEditor
pub fn new() -> Self
pub fn build_humanoid_skeleton(&mut self)
pub fn compute_total_mass(&mut self)
Sourcepub fn compute_blended_transforms(
&self,
physics_poses: &HashMap<String, (Vec3, Quat)>,
animation_poses: &HashMap<String, (Vec3, Quat)>,
) -> HashMap<String, (Vec3, Quat)>
pub fn compute_blended_transforms( &self, physics_poses: &HashMap<String, (Vec3, Quat)>, animation_poses: &HashMap<String, (Vec3, Quat)>, ) -> HashMap<String, (Vec3, Quat)>
Blend bone transforms between ragdoll physics and animation Returns blended world transform for each bone
Sourcepub fn muscle_torque(
&self,
joint: &RagdollJoint,
bone_name: &str,
current_angle: f32,
target_angle: f32,
) -> f32
pub fn muscle_torque( &self, joint: &RagdollJoint, bone_name: &str, current_angle: f32, target_angle: f32, ) -> f32
Compute muscle spring torque for a joint given current angle
pub fn set_blend_mode(&mut self, mode: RagdollBlendMode, blend_time: f32)
pub fn update_blend(&mut self, dt: f32)