pub struct VoronoiFracture {
pub cells: Vec<VoronoiCell>,
pub bounds_min: Vec3,
pub bounds_max: Vec3,
pub num_cells: usize,
pub material_strength: f32,
pub toughness: f32,
pub density: f32,
pub cracks: Vec<(usize, usize)>,
pub debris_particles: Vec<DebrisParticle>,
pub fractured: bool,
}Fields
cells: Vec<VoronoiCell>bounds_min: Vec3bounds_max: Vec3num_cells: usizematerial_strength: f32toughness: f32density: f32cracks: Vec<(usize, usize)>debris_particles: Vec<DebrisParticle>fractured: boolImplementations
Sourceimpl VoronoiFracture
impl VoronoiFracture
pub fn new( bounds_min: Vec3, bounds_max: Vec3, num_cells: usize, seed: u64, ) -> Self
Sourcepub fn find_cell(&self, point: Vec3) -> usize
pub fn find_cell(&self, point: Vec3) -> usize
For each point, find the nearest Voronoi seed (Lloyd-style cell assignment)
Sourcepub fn accumulate_stress(
&mut self,
cell_idx: usize,
force_magnitude: f32,
contact_area: f32,
)
pub fn accumulate_stress( &mut self, cell_idx: usize, force_magnitude: f32, contact_area: f32, )
Accumulate stress on a cell given an impulse force
Sourcepub fn check_fracture(&mut self) -> Vec<usize>
pub fn check_fracture(&mut self) -> Vec<usize>
Check if any cells exceed strength threshold and initiate fracture
Sourcepub fn propagate_cracks(&mut self, initial_cells: &[usize])
pub fn propagate_cracks(&mut self, initial_cells: &[usize])
Propagate crack from a fractured cell to neighbors
Sourcepub fn spawn_debris(&mut self, impact_velocity: Vec3, rng: &mut FractureRng)
pub fn spawn_debris(&mut self, impact_velocity: Vec3, rng: &mut FractureRng)
Spawn debris from fractured cells
Sourcepub fn integrate_debris(&mut self, dt: f32)
pub fn integrate_debris(&mut self, dt: f32)
Integrate debris particles
Sourcepub fn are_connected(&self, a: usize, b: usize) -> bool
pub fn are_connected(&self, a: usize, b: usize) -> bool
Check if two cells are still connected (no crack between them)