Module render_graph_editor

Module render_graph_editor 

Structs

ACESTransform
AccessFlags
AdaptiveResolutionScaler
AnnotationManager
AsyncComputeGroup
AsyncComputeScheduler
AtlasRegion
AttachmentDescription
AutoExposurePassDesc
BandwidthProfiler
BloomPassDesc
BloomUniforms
BufferBarrier
BufferDesc
CapturedFrame
ClusteredLightGrid
ColorBlendAttachment
ColorBlendState
CompilationReport
CompiledRenderGraph
CriticalPathAnalyzer
DDGIPassDesc
DebugPassDesc
DecalPassDesc
DependencyMatrix
DepthOfFieldPassDesc
DepthStencilState
DescriptorBinding
DescriptorSet
DrawCommand
EditorHistory
EditorRenderer
FormatInfo
FrameDebugger
FrameStatistics
FrameUniforms
GBufferPassDesc
GPUCullingPassDesc
GTAOPassDesc
GpuMemoryBudget
GraphLayout
HiZTracer
HotReloadManager
ImageBarrier
LensFlarePassDesc
LightCullingPassDesc
LightingPassDesc
MotionBlurPassDesc
MultisampleState
NodeAnnotation
NodeConnection
NodePin
OcclusionCuller
OverdrawEstimator
ParticlePassDesc
PassGroup
PassGroupManager
PassId
PassNode
PassReorderer
PassStatistics
PipelineBarrier
PipelineCache
PipelineKey
PipelinePreset
PipelineStageFlags
PostFxChain
ProfilingManager
QueryPool
RTPassDesc
RasterizerState
RenderGraphCompiler
RenderGraphEditor
RenderGraphResource
RenderGraphValidator
RenderPassDescription
ResolvePassDesc
ResourceAccessRecord
ResourceId
ResourceNodeVisual
SSAOPassDesc
SSAOUniforms
SSRPassDesc
SSSPassDesc
SerializedNode
SerializedRenderGraph
SerializedResource
ShadowAtlas
ShadowMapPassDesc
ShadowUniforms
SkyPassDesc
StencilOpState
SubpassDependency
SubpassDescription
SugiyamaLayout
TAAPassDesc
TAAUniforms
TBRDetector
TemporalHistoryBuffer
TextureDesc
TimestampQuery
ToneMappingPassDesc
UIPassDesc
UpscalePassDesc
VXGIPassDesc
ValidationReport
VertexAttribute
VertexBinding
VertexInputLayout
VolumetricFogPassDesc

Enums

AOAlgorithm
BindingType
BlendFactor
BlendOp
CompareOp
ComputeQueue
CullMode
DoFAlgorithm
DrawCommandKind
EditorAction
EyeAdaptation
FillMode
FrontFace
GraphDiff
ImageLayout
LoadOp
LogicOp
PassDesc
PassKind
PinKind
PostFxEffect
QueryType
RTDenoiser
RTPassKind
ResourceDesc
ResourceKind
ResourceLifetime
SSSAlgorithm
SampleCount
ShadowMapKind
SkyModel
StencilOp
StoreOp
TextureFormat
ToneMappingOperator
UpscalerKind
ValidationError
VertexFormat
VertexInputRate

Functions

aabb_in_frustum
Test AABB against frustum planes
aabb_intersect
align_up
align_up_u32
bake_tonemapping_lut
build_forward_plus_pipeline
build_lighting_descriptor_set
build_mobile_deferred_pipeline
build_ssao_descriptor_set
clamp01
compute_mip_count
compute_texture_lod
Compute mip level for texture sampling based on UV footprint (OpenGL-style)
cook_torrance_brdf
decode_rgbe
decode_velocity
diff_render_graphs
encode_rgb9e5
Shared exponent (GL_RGB9_E5) encoding
encode_rgbe
RGBE encoding (Radiance HDR format) for efficient HDR storage
encode_velocity
Encode/decode velocity to/from RG16F
ev100_to_exposure
Exposure compensation from EV100
export_dot
export_mermaid
format_channel_bits
Get the number of bits in each channel
format_info
formats_compatible
Check if two formats are compatible for aliasing (same memory layout requirements)
frustum_planes_from_view_proj
ggx_distribution
halton_sequence
hex_distance
importance_sample_ggx
integrate_brdf
Pre-integrated BRDF LUT sample (GGX + Schlick)
is_color_attachment_format
Can the format be used as a color attachment?
is_depth_stencil_attachment_format
Can the format be used as a depth/stencil attachment?
layout_to_dst_info
Map an image layout to the typical pipeline stage/access for a destination (before that usage)
layout_to_src_info
Map an image layout to the typical pipeline stage/access for a source (after that usage)
lerp
lerp_vec3
linear_depth_to_ndc
Convert a linear depth value to a NDC z for a given near/far
linear_to_srgb
linear_to_srgb_channel
linearize_depth
Linearize depth from non-linear depth buffer
luminance
Luminance (CIE Y)
octahedral_decode
Octahedral decode normal
octahedral_encode
Octahedral encode normal (for RG16F GBuffer storage)
pack_material
Encode/decode RGBA8 packed normal+roughness (for material GBuffer)
rec709_to_xyz
reconstruct_world_pos
Reconstruct world-space position from depth buffer
schlick_fresnel
smith_g1_ggx
smith_g_ggx
smoothstep
sphere_in_frustum
Test sphere against frustum planes
sphere_intersect
sphere_screen_size_pixels
Compute the screen-space size of a sphere in pixels
srgb_channel_to_linear
srgb_eotf
Linearize a gamma-encoded value using the sRGB piecewise transfer function
srgb_oetf
sRGB inverse EOTF (linear to display-encoded)
srgb_to_linear
Convert sRGB to linear (approximate gamma 2.2)
texture_size_bytes
unpack_material
view_direction_from_uv
world_to_screen_uv
Compute screen-space UV from world position
xyz_to_aces_ap0
xyz_to_rec709