pub fn layout_to_dst_info(
layout: ImageLayout,
) -> (PipelineStageFlags, AccessFlags)Expand description
Map an image layout to the typical pipeline stage/access for a destination (before that usage)
pub fn layout_to_dst_info(
layout: ImageLayout,
) -> (PipelineStageFlags, AccessFlags)Map an image layout to the typical pipeline stage/access for a destination (before that usage)