pub struct DecalPassDesc {
pub width: u32,
pub height: u32,
pub output_albedo: ResourceId,
pub output_normal: ResourceId,
pub input_depth: ResourceId,
pub max_decals: u32,
pub blend: ColorBlendAttachment,
pub depth_stencil: DepthStencilState,
}Fields
width: u32height: u32output_albedo: ResourceIdoutput_normal: ResourceIdinput_depth: ResourceIdmax_decals: u32blend: ColorBlendAttachmentdepth_stencil: DepthStencilStateImplementations
Sourceimpl DecalPassDesc
impl DecalPassDesc
pub fn default(width: u32, height: u32) -> Self
Sourcepub fn decal_clip_bounds(
decal_world_to_local: Mat4,
view_proj: Mat4,
) -> (Vec3, Vec3)
pub fn decal_clip_bounds( decal_world_to_local: Mat4, view_proj: Mat4, ) -> (Vec3, Vec3)
A decal is rendered as a unit cube in world-space; the projection back to screen-space uses the GBuffer depth to compute the world position of each fragment. This function computes the OBB (oriented bounding box) of a decal in clip space.