pub struct RenderGraphResource {
pub id: ResourceId,
pub name: String,
pub desc: ResourceDesc,
pub lifetime: ResourceLifetime,
pub first_use: usize,
pub last_use: usize,
pub can_alias: bool,
pub alias_target: Option<ResourceId>,
pub current_layout: ImageLayout,
}Fields
id: ResourceIdname: Stringdesc: ResourceDesclifetime: ResourceLifetimefirst_use: usizeThe pass range [first_write_pass, last_read_pass] (index into sorted pass list)
last_use: usizecan_alias: boolWhether this resource can share physical memory with another
alias_target: Option<ResourceId>If aliased, the physical resource id it is assigned to
current_layout: ImageLayoutCurrent layout (updated during barrier analysis)
Implementations
Sourceimpl RenderGraphResource
impl RenderGraphResource
pub fn new_transient_texture( id: ResourceId, name: &str, desc: TextureDesc, ) -> Self
pub fn is_texture(&self) -> bool
pub fn texture_desc(&self) -> Option<&TextureDesc>
Sourcepub fn can_alias_with(&self, other: &RenderGraphResource) -> bool
pub fn can_alias_with(&self, other: &RenderGraphResource) -> bool
Two transient resources can alias if their lifetimes don’t overlap
Sourcepub fn lifetime_overlaps(&self, other: &RenderGraphResource) -> bool
pub fn lifetime_overlaps(&self, other: &RenderGraphResource) -> bool
Lifetimes overlap if [first_use, last_use] intervals intersect