ShaderNodeKind

Enum ShaderNodeKind 

pub enum ShaderNodeKind {
Show 129 variants ConstFloat(f32), ConstVec2([f32; 2]), ConstVec3([f32; 3]), ConstVec4([f32; 4]), ConstInt(i32), ConstBool(bool), Time, Resolution, FragCoord, VertexNormal, VertexTangent, VertexUV, VertexUV2, VertexColor, WorldPosition, ViewDirection, CameraPosition, ModelMatrix, ViewMatrix, ProjectionMatrix, NormalMatrix, CustomUniformFloat { name: String, }, CustomUniformVec3 { name: String, }, CustomUniformVec4 { name: String, }, CustomUniformSampler2D { name: String, }, Add, Subtract, Multiply, Divide, Power, SquareRoot, AbsoluteValue, Negate, OneMinus, Reciprocal, Floor, Ceiling, Round, Fraction, Sign, Modulo, Min, Max, Clamp, Saturate, Lerp, SmoothStep, Step, Sin, Cos, Tan, Asin, Acos, Atan, Atan2, Degrees, Radians, Exp, Exp2, Log, Log2, Dot, Cross, Length, Normalize, Reflect, Refract, FaceForward, Distance, Mix, VectorSplit, VectorMerge, VectorSwizzle { swizzle: [u8; 4], out_count: u8, }, MatrixMultiply, MatrixTranspose, MatrixInverse, TransformPoint, TransformVector, TransformNormal, SampleTexture2D, SampleTextureCube, SampleTexture2DLod, SampleTexture2DGrad, SampleNormalMap, TextureSize, ColorToLinear, ColorToGamma, HsvToRgb, RgbToHsv, Luminance, ColorBalance, Hue, Saturation, Brightness, FresnelSchlick, GGXDistribution, SmithGeometry, BRDFSpecular, BRDFDiffuse, EnvBRDFApprox, SubsurfaceApprox, EmissionBlend, SdfSample { sdf_graph_id: u32, }, SdfNormal { sdf_graph_id: u32, }, SdfAO { sdf_graph_id: u32, }, IfElse, IsNaN, IsInf, Dpdx, Dpdy, FWidth, Noise2D, Noise3D, VoronoiNoise, FbmNoise { octaves: u8, }, CellularNoise, WhiteNoise, GradientNoise, PbrOutput, UnlitOutput, PostProcessOutput, CustomOutput { name: String, value_type: ShaderValueType, }, VertexOffset, DepthOutput, CustomVarying { name: String, value_type: ShaderValueType, }, Reroute, Comment { text: String, width: f32, height: f32, }, Group { label: String, nodes: Vec<ShaderNodeId>, }, SubGraph { graph_id: u32, label: String, },
}

Variants



ConstFloat(f32)



ConstVec2([f32; 2])



ConstVec3([f32; 3])



ConstVec4([f32; 4])



ConstInt(i32)



ConstBool(bool)



Time



Resolution



FragCoord



VertexNormal



VertexTangent



VertexUV



VertexUV2



VertexColor



WorldPosition



ViewDirection



CameraPosition



ModelMatrix



ViewMatrix



ProjectionMatrix



NormalMatrix



CustomUniformFloat

Fields

name: String


CustomUniformVec3

Fields

name: String


CustomUniformVec4

Fields

name: String


CustomUniformSampler2D

Fields

name: String


Add



Subtract



Multiply



Divide



Power



SquareRoot



AbsoluteValue



Negate



OneMinus



Reciprocal



Floor



Ceiling



Round



Fraction



Sign



Modulo



Min



Max



Clamp



Saturate



Lerp



SmoothStep



Step



Sin



Cos



Tan



Asin



Acos



Atan



Atan2



Degrees



Radians



Exp



Exp2



Log



Log2



Dot



Cross



Length



Normalize



Reflect



Refract



FaceForward



Distance



Mix



VectorSplit



VectorMerge



VectorSwizzle

Fields

swizzle: [u8; 4]
out_count: u8


MatrixMultiply



MatrixTranspose



MatrixInverse



TransformPoint



TransformVector



TransformNormal



SampleTexture2D



SampleTextureCube



SampleTexture2DLod



SampleTexture2DGrad



SampleNormalMap



TextureSize



ColorToLinear



ColorToGamma



HsvToRgb



RgbToHsv



Luminance



ColorBalance



Hue



Saturation



Brightness



FresnelSchlick



GGXDistribution



SmithGeometry



BRDFSpecular



BRDFDiffuse



EnvBRDFApprox



SubsurfaceApprox



EmissionBlend



SdfSample

Fields

sdf_graph_id: u32


SdfNormal

Fields

sdf_graph_id: u32


SdfAO

Fields

sdf_graph_id: u32


IfElse



IsNaN



IsInf



Dpdx



Dpdy



FWidth



Noise2D



Noise3D



VoronoiNoise



FbmNoise

Fields

octaves: u8


CellularNoise



WhiteNoise



GradientNoise



PbrOutput



UnlitOutput



PostProcessOutput



CustomOutput

Fields

name: String
value_type: ShaderValueType


VertexOffset



DepthOutput



CustomVarying

Fields

name: String
value_type: ShaderValueType


Reroute



Comment

Fields

text: String
width: f32
height: f32


Group

Fields

label: String


SubGraph

Fields

graph_id: u32
label: String

Implementations

Source

impl ShaderNodeKind

pub fn label(&self) -> String

pub fn category(&self) -> &'static str

pub fn port_definitions(&self) -> (Vec<PortDef>, Vec<PortDef>)

Returns (input_ports, output_ports)

pub fn emit_glsl(&self, inputs: &[String], var: &str) -> String

Emit GLSL expression for this node given named expressions for each input.