pub fn chord_deviation(spline: &CatmullRomSpline) -> Vec<f32>Expand description
Compute the deviation of each control point from the chord (first to last).
pub fn chord_deviation(spline: &CatmullRomSpline) -> Vec<f32>Compute the deviation of each control point from the chord (first to last).