pub struct CatmullRomSpline {
pub control_points: Vec<ControlPoint>,
pub closed: bool,
pub alpha: f32,
/* private fields */
}Fields
control_points: Vec<ControlPoint>closed: boolalpha: f32Implementations
Sourceimpl CatmullRomSpline
impl CatmullRomSpline
pub fn new(points: Vec<Vec3>, alpha: f32, closed: bool) -> Self
Sourcepub fn eval_segment(&self, seg: usize, u: f32) -> Vec3
pub fn eval_segment(&self, seg: usize, u: f32) -> Vec3
Evaluate position at local segment parameter u in [0,1]
pub fn evaluate_derivative(&self, t: f32) -> Vec3
pub fn evaluate_second_derivative(&self, t: f32) -> Vec3
pub fn evaluate_third_derivative(&self, t: f32) -> Vec3
pub fn frenet_frame_at(&self, t: f32) -> FrenetFrame
pub fn rebuild_arc_length_table(&mut self)
pub fn total_arc_length(&self) -> f32
pub fn t_at_arc_length(&self, s: f32) -> f32
pub fn evaluate_at_arc_length(&self, s: f32) -> Vec3
pub fn curvature_at(&self, t: f32) -> f32
pub fn torsion_at(&self, t: f32) -> f32
Sourcepub fn nearest_point(&self, query: Vec3) -> (f32, Vec3)
pub fn nearest_point(&self, query: Vec3) -> (f32, Vec3)
Nearest point on spline via binary search + Newton refinement
Sourcepub fn insert_knot(&mut self, t: f32)
pub fn insert_knot(&mut self, t: f32)
Insert a knot at parameter t, splitting a segment
pub fn split_at(&self, t: f32) -> (CatmullRomSpline, CatmullRomSpline)
pub fn join(a: CatmullRomSpline, b: CatmullRomSpline) -> CatmullRomSpline
pub fn toggle_closed(&mut self)
pub fn bounding_box(&self) -> (Vec3, Vec3)