pub struct CurvatureComb {
pub base_points: Vec<Vec3>,
pub comb_tips: Vec<Vec3>,
pub curvatures: Vec<f32>,
}Expand description
Compute a curvature comb: for each sample point, a line from the point in the normal direction scaled by curvature * scale.
Fields
base_points: Vec<Vec3>comb_tips: Vec<Vec3>curvatures: Vec<f32>Implementations
Sourceimpl CurvatureComb
impl CurvatureComb
pub fn compute(spline: &CatmullRomSpline, samples: usize, scale: f32) -> Self
Sourcepub fn max_height(&self) -> f32
pub fn max_height(&self) -> f32
Maximum curvature comb height.