pub struct BiomeSystem {
pub descriptors: Vec<BiomeDescriptor>,
}Fields
descriptors: Vec<BiomeDescriptor>Implementations
Sourceimpl BiomeSystem
impl BiomeSystem
pub fn new() -> Self
Sourcepub fn sample(
&self,
temp: f32,
humidity: f32,
altitude: f32,
) -> BiomeBlendSample
pub fn sample( &self, temp: f32, humidity: f32, altitude: f32, ) -> BiomeBlendSample
Full biome blend at a point using gaussian weighting
Sourcepub fn transition_factor(
&self,
biome_a: BiomeId,
biome_b: BiomeId,
temp: f32,
humidity: f32,
altitude: f32,
) -> f32
pub fn transition_factor( &self, biome_a: BiomeId, biome_b: BiomeId, temp: f32, humidity: f32, altitude: f32, ) -> f32
Classify transition zone between two biomes (returns a blend factor 0..1)
Sourcepub fn wind_speed(&self, sample: &BiomeBlendSample) -> f32
pub fn wind_speed(&self, sample: &BiomeBlendSample) -> f32
Get wind speed interpolated across biome weights at a sample