Screen effects coordinator — combines all post-processing passes into a single, driven, event-triggered system.
Modules
- field_
viz - Force field visualization — renders directional arrows on a grid showing the direction and strength of combined force fields in the scene.
Structs
- Effect
Presets - Pre-baked effect sequences for common scenarios.
- Effects
Controller - The master effects coordinator.
Enums
- Effect
Event - High-level game events that trigger post-processing effects.