pub fn boris_push(particle: &mut ChargedParticle, e: Vec3, b: Vec3, dt: f32)Expand description
Boris algorithm for advancing a charged particle in EM fields. This is the standard velocity-Verlet-like scheme that exactly conserves energy in a pure magnetic field.