pub struct ChargedParticleSystem {
pub particles: Vec<ChargedParticle>,
pub uniform_e: Vec3,
pub uniform_b: Vec3,
}Expand description
Manages a collection of charged particles with field evaluation.
Fields
particles: Vec<ChargedParticle>uniform_e: Vec3uniform_b: Vec3Implementations
Sourceimpl ChargedParticleSystem
impl ChargedParticleSystem
pub fn new() -> Self
pub fn add_particle(&mut self, particle: ChargedParticle)
Sourcepub fn total_kinetic_energy(&self) -> f32
pub fn total_kinetic_energy(&self) -> f32
Total kinetic energy of all particles.
Sourcepub fn total_momentum(&self) -> Vec3
pub fn total_momentum(&self) -> Vec3
Total momentum.
Sourcepub fn e_field_at(&self, pos: Vec3) -> Vec3
pub fn e_field_at(&self, pos: Vec3) -> Vec3
Evaluate the E field at a point including contributions from all particles (Coulomb fields from each particle, treated as point charges).
Sourcepub fn step_self_consistent(&mut self, dt: f32)
pub fn step_self_consistent(&mut self, dt: f32)
Step with self-consistent fields (N-body Coulomb + uniform B). O(N^2) — fine for small N.