induced_surface_charge

Function induced_surface_charge 

pub fn induced_surface_charge(cage: &FaradayCage, e_external: Vec3) -> Vec<f32>
Compute induced surface charge density on the cage boundary due to an external E field. The surface charge is proportional to the normal component of the external field.