pub fn add_branches(bolt: &mut LightningBolt, probability: f32, seed: &mut u64)Expand description
Add branches to an existing bolt. Each segment has a probability of spawning a short branch.
pub fn add_branches(bolt: &mut LightningBolt, probability: f32, seed: &mut u64)Add branches to an existing bolt. Each segment has a probability of spawning a short branch.