pub fn format_for(path: &Path) -> Option<ImageFormat>Expand description
The format a path’s extension asks for, if the image crate can write it.
pub fn format_for(path: &Path) -> Option<ImageFormat>The format a path’s extension asks for, if the image crate can write it.