pub struct CrushingWalls {Show 16 fields
pub left_wall_pos: f32,
pub right_wall_pos: f32,
pub left_start: f32,
pub right_start: f32,
pub close_speed: f32,
pub wall_height: f32,
pub wall_y: f32,
pub min_gap: f32,
pub damage_per_second: f32,
pub is_active: bool,
pub is_stopped: bool,
pub push_force: f32,
pub left_wall_id: Option<ObjectId>,
pub right_wall_id: Option<ObjectId>,
pub power_source_id: Option<ObjectId>,
pub power_source_health: f32,
}Expand description
Crushing walls trap.
Fields
left_wall_pos: f32right_wall_pos: f32left_start: f32right_start: f32close_speed: f32wall_height: f32wall_y: f32min_gap: f32damage_per_second: f32is_active: boolis_stopped: boolpush_force: f32left_wall_id: Option<ObjectId>right_wall_id: Option<ObjectId>power_source_id: Option<ObjectId>power_source_health: f32Implementations
Sourceimpl CrushingWalls
impl CrushingWalls
pub fn new( left_x: f32, right_x: f32, wall_y: f32, wall_height: f32, damage: f32, ) -> Self
Sourcepub fn damage_power_source(&mut self, amount: f32) -> bool
pub fn damage_power_source(&mut self, amount: f32) -> bool
Damage the power source. Returns true if destroyed.
Sourcepub fn spawn(&mut self, world: &mut PhysicsWorld)
pub fn spawn(&mut self, world: &mut PhysicsWorld)
Spawn wall physics objects.
Sourcepub fn update(&mut self, dt: f32, world: &mut PhysicsWorld)
pub fn update(&mut self, dt: f32, world: &mut PhysicsWorld)
Update the crushing walls.
Sourcepub fn is_being_crushed(&self, point: Vec2) -> bool
pub fn is_being_crushed(&self, point: Vec2) -> bool
Check if a point is being crushed between the walls.
Sourcepub fn push_direction(&self, point: Vec2) -> Vec2
pub fn push_direction(&self, point: Vec2) -> Vec2
Get push direction for an entity between the walls.