pub struct PlayerRobe {
pub strips: Vec<ClothStrip>,
pub attachment_offsets: Vec<Vec3>,
pub player_position: Vec3,
pub prev_player_position: Vec3,
}Expand description
2-3 short cloth strips for the mage class, swaying with player movement.
Fields
strips: Vec<ClothStrip>attachment_offsets: Vec<Vec3>Local offsets where each strip attaches to the player.
player_position: Vec3prev_player_position: Vec3Implementations