pub struct QuantumBlob {
pub blob: SoftBodyBlob,
pub eigenstate: u8,
pub superposed: bool,
}Expand description
A soft body that oscillates between two shapes (Eigenstate boss mechanic). The frequency can be configured and represents the quantum superposition oscillation.
Fields
blob: SoftBodyBlobeigenstate: u8Current eigenstate (0 or 1), toggled on “collapse”.
superposed: boolWhether currently oscillating (superposition) or collapsed.
Implementations
Sourceimpl QuantumBlob
impl QuantumBlob
Sourcepub fn new(
center: Vec3,
radius: f32,
resolution: usize,
shape_a: Vec<Vec3>,
shape_b: Vec<Vec3>,
frequency: f32,
) -> Self
pub fn new( center: Vec3, radius: f32, resolution: usize, shape_a: Vec<Vec3>, shape_b: Vec<Vec3>, frequency: f32, ) -> Self
Create a quantum blob with two shape configurations.
Sourcepub fn new_default(
center: Vec3,
radius: f32,
resolution: usize,
frequency: f32,
) -> Self
pub fn new_default( center: Vec3, radius: f32, resolution: usize, frequency: f32, ) -> Self
Create with default shapes: circle (shape A) and elongated ellipse (shape B).
Sourcepub fn collapse(&mut self, state: u8)
pub fn collapse(&mut self, state: u8)
Collapse the superposition to one eigenstate. Stops oscillation.
Sourcepub fn enter_superposition(&mut self, frequency: f32)
pub fn enter_superposition(&mut self, frequency: f32)
Resume superposition oscillation.
pub fn get_hull(&self) -> Vec<Vec3>
pub fn center_position(&self) -> Vec3