pub struct RopeChain {
pub points: Vec<VerletPoint>,
pub constraints: Vec<DistanceConstraint>,
pub lifetime: f32,
pub age: f32,
}Expand description
A chain of point masses connected by distance constraints, forming a rope.
Fields
points: Vec<VerletPoint>constraints: Vec<DistanceConstraint>lifetime: f32Maximum simulation lifetime in seconds. 0 = infinite.
age: f32Implementations
Sourceimpl RopeChain
impl RopeChain
Sourcepub fn new(start: Vec3, end: Vec3, segments: usize) -> Self
pub fn new(start: Vec3, end: Vec3, segments: usize) -> Self
Create a rope from start to end with segments links.
Sourcepub fn attach_start(&mut self, pos: Vec3)
pub fn attach_start(&mut self, pos: Vec3)
Fix the start point at a position.
Sourcepub fn attach_end(&mut self, pos: Vec3)
pub fn attach_end(&mut self, pos: Vec3)
Fix the end point at a position.
Sourcepub fn apply_gravity(&mut self)
pub fn apply_gravity(&mut self)
Apply standard gravity to all points.
Sourcepub fn sever_at(&mut self, segment_index: usize) -> Option<RopeChain>
pub fn sever_at(&mut self, segment_index: usize) -> Option<RopeChain>
Sever the rope at a segment index, returning a new RopeChain for the
detached portion (from the cut point to the end). The current rope is
truncated to end at the cut point.
Sourcepub fn get_points(&self) -> Vec<Vec3>
pub fn get_points(&self) -> Vec<Vec3>
Get positions of all points.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if this rope has expired.
Sourcepub fn current_length(&self) -> f32
pub fn current_length(&self) -> f32
Total length of the rope (sum of segment distances).
Sourcepub fn apply_force(&mut self, force: Vec3)
pub fn apply_force(&mut self, force: Vec3)
Apply a force to all points.