pub struct SlimeEnemy {
pub blob: SoftBodyBlob,
pub hp: f32,
pub max_hp: f32,
pub base_stiffness: f32,
pub min_stiffness: f32,
}Expand description
A soft body blob that deforms on hit, jiggles, and reforms. Lower HP results in more wobbly behavior (lower spring stiffness).
Fields
blob: SoftBodyBlobhp: f32max_hp: f32base_stiffness: f32Base stiffness at full HP.
min_stiffness: f32Minimum stiffness at zero HP.
Implementations
Sourceimpl SlimeEnemy
impl SlimeEnemy
pub fn new(center: Vec3, radius: f32, resolution: usize, max_hp: f32) -> Self
Sourcepub fn take_hit(&mut self, direction: Vec3, force: f32, damage: f32)
pub fn take_hit(&mut self, direction: Vec3, force: f32, damage: f32)
Take damage from a hit in a given direction.
pub fn is_dead(&self) -> bool
pub fn get_hull(&self) -> Vec<Vec3>
pub fn center_position(&self) -> Vec3