pub struct SoftBodyBlob {
pub points: Vec<VerletPoint>,
pub constraints: Vec<DistanceConstraint>,
pub center_index: usize,
pub perimeter_count: usize,
pub spring_stiffness: f32,
pub shape_a: Vec<Vec3>,
pub shape_b: Vec<Vec3>,
pub morph_frequency: f32,
pub morph_time: f32,
pub morphing: bool,
pub lifetime: f32,
pub age: f32,
}Expand description
A spring-connected mesh of points forming a deformable 2D blob (circle of perimeter points plus a center point).
Fields
points: Vec<VerletPoint>constraints: Vec<DistanceConstraint>center_index: usizeperimeter_count: usizespring_stiffness: f32shape_a: Vec<Vec3>Morph target shapes: each is a list of offsets from center.
shape_b: Vec<Vec3>morph_frequency: f32morph_time: f32morphing: boollifetime: f32Maximum simulation lifetime in seconds. 0 = infinite.
age: f32Implementations
Sourceimpl SoftBodyBlob
impl SoftBodyBlob
Sourcepub fn new(center: Vec3, radius: f32, resolution: usize) -> Self
pub fn new(center: Vec3, radius: f32, resolution: usize) -> Self
Create a blob centered at center with the given radius and
resolution (number of perimeter points).
Sourcepub fn apply_hit(&mut self, direction: Vec3, force: f32)
pub fn apply_hit(&mut self, direction: Vec3, force: f32)
Apply a hit that deforms the blob in a direction.
Sourcepub fn oscillate_between(
&mut self,
shape_a: Vec<Vec3>,
shape_b: Vec<Vec3>,
frequency: f32,
)
pub fn oscillate_between( &mut self, shape_a: Vec<Vec3>, shape_b: Vec<Vec3>, frequency: f32, )
Set up oscillation between two shape configurations.
shape_a and shape_b are lists of offsets from center for each point.
Sourcepub fn set_stiffness(&mut self, stiffness: f32)
pub fn set_stiffness(&mut self, stiffness: f32)
Set spring stiffness (affects constraint solving pressure and morph force).
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if this blob has expired.
Sourcepub fn center_position(&self) -> Vec3
pub fn center_position(&self) -> Vec3
Get the center position.