pub enum FloorBiome {
Ruins,
Crypt,
Library,
Forge,
Garden,
Void,
Chaos,
Abyss,
Cathedral,
Laboratory,
}Expand description
Biome determines the visual theme, hazards, and ambient feel of a floor.
Variants
Implementations
Sourceimpl FloorBiome
impl FloorBiome
Sourcepub fn properties(self) -> BiomeProperties
pub fn properties(self) -> BiomeProperties
Return the static properties for this biome.
Sourcepub fn from_dungeon_theme(theme: DungeonTheme) -> Self
pub fn from_dungeon_theme(theme: DungeonTheme) -> Self
Convert a DungeonTheme from the procedural module to the closest biome.
Sourcepub fn to_dungeon_theme(self) -> DungeonTheme
pub fn to_dungeon_theme(self) -> DungeonTheme
Get the DungeonTheme most closely matching this biome.