pub struct DungeonManager { /* private fields */ }Expand description
Top-level manager for dungeon exploration across multiple floors.
Implementations
Sourceimpl DungeonManager
impl DungeonManager
Sourcepub fn current_floor(&self) -> Option<&Floor>
pub fn current_floor(&self) -> Option<&Floor>
Get a reference to the current floor.
Sourcepub fn current_floor_mut(&mut self) -> Option<&mut Floor>
pub fn current_floor_mut(&mut self) -> Option<&mut Floor>
Get a mutable reference to the current floor.
Sourcepub fn get_room_at(&self, pos: IVec2) -> Option<&DungeonRoom>
pub fn get_room_at(&self, pos: IVec2) -> Option<&DungeonRoom>
Get the room at a given position on the current floor.
Sourcepub fn reveal_around(&mut self, pos: IVec2, radius: i32)
pub fn reveal_around(&mut self, pos: IVec2, radius: i32)
Reveal tiles around a position on the current floor.
Sourcepub fn floor_number(&self) -> u32
pub fn floor_number(&self) -> u32
Get the current floor number.
Sourcepub fn history_size(&self) -> usize
pub fn history_size(&self) -> usize
How many floors are stored in history.