pub struct RoomPopulator;Expand description
Populates rooms with enemies, items, and interactables based on type.
Implementations
Sourceimpl RoomPopulator
impl RoomPopulator
Sourcepub fn populate(
room: &mut DungeonRoom,
floor: u32,
corruption: u32,
biome: FloorBiome,
rng: &mut Rng,
)
pub fn populate( room: &mut DungeonRoom, floor: u32, corruption: u32, biome: FloorBiome, rng: &mut Rng, )
Populate a room based on its type, floor depth, and biome.