pub struct CorruptionAudioProcessor {
pub corruption_level: f32,
pub tier: CorruptionTier,
pub pitch_wobble: PitchWobble,
pub rhythm_drift: RhythmDrift,
pub filter_mod: FilterModulationEffect,
pub granular: GranularArtifacts,
}Expand description
Master corruption audio processor — owns all degradation effects.
Fields
corruption_level: f32tier: CorruptionTierpitch_wobble: PitchWobblerhythm_drift: RhythmDriftfilter_mod: FilterModulationEffectgranular: GranularArtifactsImplementations
Sourceimpl CorruptionAudioProcessor
impl CorruptionAudioProcessor
pub fn new() -> Self
Sourcepub fn process_corruption(&mut self, corruption: u32)
pub fn process_corruption(&mut self, corruption: u32)
Update all degradation parameters from a corruption value (0-500+).
Sourcepub fn apply(&mut self, sample: f32) -> f32
pub fn apply(&mut self, sample: f32) -> f32
Apply all active corruption effects to a single audio sample.
Sourcepub fn beat_offset(&mut self, beat_index: u32) -> f32
pub fn beat_offset(&mut self, beat_index: u32) -> f32
Return a beat offset to apply to the next note (rhythm drift).