pub struct MsdfGlyphData {
pub r_channel: Vec<u8>,
pub g_channel: Vec<u8>,
pub b_channel: Vec<u8>,
pub width: u32,
pub height: u32,
pub advance: f32,
pub bearing_x: f32,
pub bearing_y: f32,
pub bbox_w: f32,
pub bbox_h: f32,
}Expand description
Multi-channel SDF result: R, G, B channels each contain distance to a different edge segment class, producing sharper corners when median-filtered.
Fields
r_channel: Vec<u8>g_channel: Vec<u8>b_channel: Vec<u8>width: u32height: u32advance: f32bearing_x: f32bearing_y: f32bbox_w: f32bbox_h: f32Trait Implementations
Sourceimpl Clone for MsdfGlyphData
impl Clone for MsdfGlyphData
Sourcefn clone(&self) -> MsdfGlyphData
fn clone(&self) -> MsdfGlyphData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MsdfGlyphData
impl RefUnwindSafe for MsdfGlyphData
impl Send for MsdfGlyphData
impl Sync for MsdfGlyphData
impl Unpin for MsdfGlyphData
impl UnsafeUnpin for MsdfGlyphData
impl UnwindSafe for MsdfGlyphData