pub struct BindingGroup {
pub name: String,
pub enabled: bool,
/* private fields */
}Expand description
A named group of bindings that can be enabled/disabled as a unit. Useful for switching between gameplay mode and menu mode.
Fields
name: Stringenabled: boolImplementations
Sourceimpl BindingGroup
impl BindingGroup
pub fn new(name: impl Into<String>, enabled: bool) -> Self
pub fn bind(&mut self, action: impl Into<Action>, binding: Binding)
pub fn bind_axis(&mut self, axis: AxisBinding)
pub fn bind_chord(&mut self, chord: ChordBinding)
pub fn actions(&self) -> impl Iterator<Item = &Action>