pub struct HemisphereLight {
pub sky_color: Color,
pub ground_color: Color,
pub intensity: f32,
pub up_direction: Vec3,
pub enabled: bool,
}Expand description
A hemisphere light with a sky color and ground color that blends based on the surface normal.
Fields
sky_color: Colorground_color: Colorintensity: f32up_direction: Vec3enabled: boolImplementations