pub struct EmissiveGlyph {
pub position: Vec3,
pub color: Color,
pub emission_strength: f32,
pub radius: f32,
pub glyph_character: char,
pub enabled: bool,
pub emission_threshold: f32,
}Expand description
Auto light source generated from a bright glyph that exceeds the emission threshold.
Fields
position: Vec3color: Coloremission_strength: f32radius: f32glyph_character: charenabled: boolemission_threshold: f32The threshold above which a glyph emission value becomes a light source.
Implementations
Sourceimpl EmissiveGlyph
impl EmissiveGlyph
pub fn new(position: Vec3, character: char, color: Color, emission: f32) -> Self
Sourcepub fn effective_intensity(&self) -> f32
pub fn effective_intensity(&self) -> f32
The effective intensity above the threshold.
Sourcepub fn irradiance_at(&self, point: Vec3) -> Color
pub fn irradiance_at(&self, point: Vec3) -> Color
Compute irradiance at a world point (treated as a small point light).
Sourcepub fn auto_radius(emission_strength: f32) -> f32
pub fn auto_radius(emission_strength: f32) -> f32
Estimate emissive glyph radius based on emission strength.