CascadedShadowMap

Struct CascadedShadowMap 

pub struct CascadedShadowMap {
    pub cascades: [ShadowMap; 4],
    pub cascade_count: u32,
    pub cascade_vp: [Mat4; 4],
    pub split_distances: [f32; 5],
    pub resolution: u32,
    pub blend_cascades: bool,
    pub blend_band: f32,
}
Shadow mapping for directional lights using cascaded shadow maps. Splits the view frustum into 4 cascades for better shadow resolution distribution.

Fields

cascades: [ShadowMap; 4]

One shadow map per cascade (up to 4).

cascade_count: u32

Number of active cascades (1..=4).

cascade_vp: [Mat4; 4]

The view-projection matrix for each cascade.

split_distances: [f32; 5]

Split distances in view space.

resolution: u32

Resolution per cascade.

blend_cascades: bool

Whether to blend between cascades.

blend_band: f32

Blend band width in normalized split space.

Implementations

Source

impl CascadedShadowMap

pub fn new(resolution: u32, cascade_count: u32) -> Self

pub fn update_splits(&mut self, params: &CascadeShadowParams)

Update cascade splits using the given parameters.

pub fn set_cascade_vp(&mut self, cascade: usize, vp: Mat4)

Set the view-projection matrix for a specific cascade.

pub fn compute_cascade_matrices( &mut self, light_dir: Vec3, camera_frustum_slices: &[[Vec3; 8]; 4], params: &CascadeShadowParams, )

Compute cascade view-projection matrices from light direction and camera frustum.

pub fn clear_all(&mut self)

Clear all cascade depth buffers.

pub fn select_cascade(&self, view_depth: f32) -> usize

Determine which cascade a view-space depth falls into.

pub fn is_in_shadow( &self, world_pos: Vec3, view_depth: f32, bias: &ShadowBias, ) -> bool

Test if a point is in shadow, using the appropriate cascade.

pub fn shadow_factor( &self, world_pos: Vec3, view_depth: f32, bias: &ShadowBias, ) -> f32

Compute shadow factor with cascade blending (0.0 = fully shadowed, 1.0 = fully lit).

pub fn compute_frustum_slice( near: f32, far: f32, fov_y: f32, aspect: f32, camera_pos: Vec3, camera_forward: Vec3, camera_up: Vec3, ) -> [Vec3; 8]

Compute frustum slice corners for a cascade given camera near/far/projection.

pub fn memory_bytes(&self) -> usize

Get total memory usage in bytes.