pub struct VolumetricSystem {
pub light_shafts: VolumetricLightShafts,
pub fog: VolumetricFog,
pub tiled_culling: Option<TiledLightCulling>,
pub clustered_assignment: Option<ClusteredLightAssignment>,
pub shafts_enabled: bool,
pub fog_enabled: bool,
pub tiled_culling_enabled: bool,
pub clustered_enabled: bool,
}Expand description
Orchestrates all volumetric effects.
Fields
light_shafts: VolumetricLightShaftsfog: VolumetricFogtiled_culling: Option<TiledLightCulling>clustered_assignment: Option<ClusteredLightAssignment>shafts_enabled: boolWhether volumetric light shafts are enabled.
fog_enabled: boolWhether volumetric fog is enabled.
tiled_culling_enabled: boolWhether tiled culling is active.
clustered_enabled: boolWhether clustered assignment is active.
Implementations
Sourceimpl VolumetricSystem
impl VolumetricSystem
pub fn new() -> Self
Sourcepub fn init_tiled_culling(&mut self, width: u32, height: u32, tile_size: u32)
pub fn init_tiled_culling(&mut self, width: u32, height: u32, tile_size: u32)
Initialize tiled light culling for the given screen resolution.
Sourcepub fn init_clustered(
&mut self,
clusters_x: u32,
clusters_y: u32,
clusters_z: u32,
near: f32,
far: f32,
fov_y: f32,
aspect: f32,
)
pub fn init_clustered( &mut self, clusters_x: u32, clusters_y: u32, clusters_z: u32, near: f32, far: f32, fov_y: f32, aspect: f32, )
Initialize clustered forward rendering.
Sourcepub fn update_tiled(
&mut self,
lights: &[(LightId, &Light)],
depth_buffer: &[f32],
)
pub fn update_tiled( &mut self, lights: &[(LightId, &Light)], depth_buffer: &[f32], )
Update tiled light culling with current lights and depth buffer.
Sourcepub fn update_clustered(&mut self, lights: &[(LightId, &Light)])
pub fn update_clustered(&mut self, lights: &[(LightId, &Light)])
Update clustered light assignment with current lights.
Sourcepub fn update_light_shaft_position(
&mut self,
light_world_pos: Vec3,
view_projection: &Mat4,
)
pub fn update_light_shaft_position( &mut self, light_world_pos: Vec3, view_projection: &Mat4, )
Update the light shaft screen position.
Sourcepub fn tiled_stats(&self) -> Option<TiledCullingStats>
pub fn tiled_stats(&self) -> Option<TiledCullingStats>
Get tiled culling stats.
Sourcepub fn clustered_stats(&self) -> Option<ClusteredStats>
pub fn clustered_stats(&self) -> Option<ClusteredStats>
Get clustered stats.