pub fn warmup(attractor: AttractorType, state: Vec3, steps: usize) -> Vec3Expand description
Warm up an attractor (discard the transient trajectory). Call before sampling to ensure the state is on the attractor.
pub fn warmup(attractor: AttractorType, state: Vec3, steps: usize) -> Vec3Warm up an attractor (discard the transient trajectory). Call before sampling to ensure the state is on the attractor.