Module field_eval

Module field_eval 

Field evaluation and sampling — evaluate the scalar field at any point, compute gradient for normals, color and emission via weighted average of source contributions.

Structs

DamageZone
Temporary damage zone that reduces field strength in an area.
FieldEvaluator
Batch field evaluator — evaluates the entity’s field with optimizations.
FieldGrid
Sampled 3D field grid.
FieldSample
Complete sample of the entity’s field at a point.