pub struct OnnxLoader;Expand description
ONNX model loader.
Implementations
Sourceimpl OnnxLoader
impl OnnxLoader
Sourcepub fn load_onnx(path: &str) -> Result<Model, String>
pub fn load_onnx(path: &str) -> Result<Model, String>
Load an ONNX model from a binary file. This implements a minimal subset of the protobuf format — enough for simple models.
The format we support is our own simplified binary:
- magic: b“ONNX“ (4 bytes)
- num_nodes: u32 LE
- For each node:
- op_type: u8 (0=Gemm,1=Conv,2=Relu,3=MaxPool,4=BatchNorm,5=Reshape,6=Softmax,7=Add,8=Mul)
- num_weights: u32 LE
- For each weight tensor: [ndim: u32] [shape…] [data as f32 LE]