pub struct AuthorityModel { /* private fields */ }Expand description
Authority tracking for a set of entities.
Implementations
Sourceimpl AuthorityModel
impl AuthorityModel
pub fn new(default_mode: AuthorityMode) -> Self
pub fn set_default_mode(&mut self, mode: AuthorityMode)
pub fn register( &mut self, entity_id: SyncEntityId, mode: AuthorityMode, owner: u32, )
pub fn unregister(&mut self, entity_id: SyncEntityId)
pub fn get_mode(&self, entity_id: SyncEntityId) -> AuthorityMode
pub fn get_owner(&self, entity_id: SyncEntityId) -> Option<u32>
pub fn set_mode(&mut self, entity_id: SyncEntityId, mode: AuthorityMode)
pub fn set_owner(&mut self, entity_id: SyncEntityId, owner: u32)
Sourcepub fn request_transfer(
&mut self,
entity_id: SyncEntityId,
target_client: u32,
timestamp_ms: u64,
) -> bool
pub fn request_transfer( &mut self, entity_id: SyncEntityId, target_client: u32, timestamp_ms: u64, ) -> bool
Request an authority transfer.
Sourcepub fn complete_transfer(&mut self, entity_id: SyncEntityId) -> bool
pub fn complete_transfer(&mut self, entity_id: SyncEntityId) -> bool
Complete a pending transfer.
Sourcepub fn cancel_transfer(&mut self, entity_id: SyncEntityId)
pub fn cancel_transfer(&mut self, entity_id: SyncEntityId)
Cancel a pending transfer.
Check whether a given client has authority over an entity.
Sourcepub fn is_transfer_pending(&self, entity_id: SyncEntityId) -> bool
pub fn is_transfer_pending(&self, entity_id: SyncEntityId) -> bool
Whether a transfer is in progress for the given entity.
pub fn entity_count(&self) -> usize