pub struct HttpResponse {
pub status: u16,
pub headers: HashMap<String, String>,
pub body: Vec<u8>,
pub text: Option<String>,
pub latency: Duration,
pub from_cache: bool,
}Expand description
A response from the server (or from the cache).
Fields
status: u16HTTP status code.
headers: HashMap<String, String>Response headers, names in lower case.
body: Vec<u8>Raw response body.
text: Option<String>Parsed as UTF-8 if possible.
latency: DurationTime from sending the request to reading the whole body.
from_cache: boolTrue if this response was served from the client’s cache.
Implementations
Sourceimpl HttpResponse
impl HttpResponse
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Status is 2xx.
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Status is 4xx.
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Status is 5xx.
Sourcepub fn is_not_modified(&self) -> bool
pub fn is_not_modified(&self) -> bool
Status is 304 Not Modified.
Sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
The content-type header.
Sourcepub fn last_modified(&self) -> Option<&str>
pub fn last_modified(&self) -> Option<&str>
The last-modified header.
Sourcepub fn json_field(&self, key: &str) -> Option<String>
pub fn json_field(&self, key: &str) -> Option<String>
A top-level field of a JSON object body, as text: strings are
returned unquoted and unescaped, other values as JSON (42, true).
None if the body is not a JSON object, has no such key, or the value
is null.