pub struct ContinuedFraction {
pub integer_part: i64,
pub coefficients: Vec<u64>,
}Expand description
A continued fraction [a0; a1, a2, …] representing a0 + 1/(a1 + 1/(a2 + …)).
Fields
integer_part: i64coefficients: Vec<u64>Implementations
Sourceimpl ContinuedFraction
impl ContinuedFraction
Sourcepub fn from_rational(num: i64, den: i64) -> Self
pub fn from_rational(num: i64, den: i64) -> Self
Build a continued fraction from a rational number p/q.
Sourcepub fn from_f64(x: f64, max_terms: usize) -> Self
pub fn from_f64(x: f64, max_terms: usize) -> Self
Build a continued fraction from a floating point number, computing up to max_terms.
Sourcepub fn convergents(&self) -> Vec<(i64, i64)>
pub fn convergents(&self) -> Vec<(i64, i64)>
Compute convergents (rational approximations) as (numerator, denominator) pairs. Returns all convergents from [a0] to [a0; a1, …, an].
pub fn is_empty(&self) -> bool