#[repr(C)]pub struct ParticleRenderInstance {
pub position: [f32; 3],
pub size: f32,
pub color: [f32; 4],
pub age_frac: f32,
pub engine_type: u32,
pub _pad: [f32; 2],
}Expand description
Per-particle data extracted from the SSBO for rendering.
In the fully GPU path, this conversion happens in a second compute pass or in the vertex shader itself. For the hybrid path, this struct is used for CPU-side extraction.
Fields
position: [f32; 3]size: f32color: [f32; 4]age_frac: f32engine_type: u32_pad: [f32; 2]Trait Implementations
Sourceimpl Clone for ParticleRenderInstance
impl Clone for ParticleRenderInstance
Sourcefn clone(&self) -> ParticleRenderInstance
fn clone(&self) -> ParticleRenderInstance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParticleRenderInstance
impl Debug for ParticleRenderInstance
impl Copy for ParticleRenderInstance
impl Pod for ParticleRenderInstance