pub struct ParticleSystem {
pub pool: ParticlePool,
pub forces: Vec<ParticleForce>,
pub position: Vec3,
pub transform: Mat4,
pub gravity: Vec3,
pub time: f32,
pub enabled: bool,
pub world_space: bool,
pub max_trail_len: usize,
/* private fields */
}Expand description
A self-contained particle system with its own pool, forces, and emitters.
Fields
pool: ParticlePoolforces: Vec<ParticleForce>position: Vec3transform: Mat4gravity: Vec3time: f32enabled: boolworld_space: boolmax_trail_len: usizeImplementations
Sourceimpl ParticleSystem
impl ParticleSystem
pub fn new(capacity: usize) -> Self
pub fn with_gravity(self, g: Vec3) -> Self
pub fn with_position(self, p: Vec3) -> Self
pub fn add_force(self, f: ParticleForce) -> Self
Sourcepub fn burst(
&mut self,
shape: &EmitterShape,
count: u32,
template: &ParticleTemplate,
)
pub fn burst( &mut self, shape: &EmitterShape, count: u32, template: &ParticleTemplate, )
Emit count particles from a shape with a template.
pub fn tick(&mut self, dt: f32)
pub fn trails(&self) -> &HashMap<usize, Vec<Vec3>>
Sourcepub fn export_gpu_buffer(&self) -> Vec<f32>
pub fn export_gpu_buffer(&self) -> Vec<f32>
Export all active particles as a GPU-ready flat buffer.