NavMesh

Struct NavMesh 

pub struct NavMesh {
    pub polys: Vec<NavPoly>,
    pub portals: Vec<NavPortal>,
    pub area_cost: AreaCost,
    /* private fields */
}
The navigation mesh: a graph of convex polygons connected by portals.

Fields

polys: Vec<NavPoly>portals: Vec<NavPortal>area_cost: AreaCost

Implementations

Source

impl NavMesh

pub fn new() -> Self

pub fn add_poly( &mut self, verts: Vec<Vec2>, area: AreaFlags, cost: f32, ) -> NavPolyId

pub fn add_portal( &mut self, poly_a: NavPolyId, poly_b: NavPolyId, left: Vec2, right: Vec2, ) -> usize

Connect two polygons through a shared edge defined by endpoints. The edge is ordered so that left and right are from the perspective of standing in poly_a looking into poly_b.

pub fn build_portals_from_edges(&mut self)

Auto-connect all pairs of adjacent polygons that share an edge.

pub fn poly_at_point(&self, p: Vec2) -> Option<NavPolyId>

pub fn poly_by_id(&self, id: NavPolyId) -> Option<&NavPoly>

pub fn closest_point_on_mesh(&self, p: Vec2) -> NavPoint

Returns the closest point on the navmesh to p.

pub fn find_path( &self, start: Vec2, end: Vec2, filter: AreaFlags, ) -> Option<NavPath>

Pathfind from start to end position, returning polygon corridor and portals.

pub fn string_pull( &self, start: Vec2, end: Vec2, _polys: &[NavPolyId], portals: &[NavPortal], ) -> Vec<Vec2>

Smooth the polygon corridor into a minimal waypoint path using funnel algorithm.