pub fn resolve_contact(
a: &mut RigidBody,
b: &mut RigidBody,
manifold: &ContactManifold,
)Expand description
Resolve a contact manifold by applying impulses to both bodies.
pub fn resolve_contact(
a: &mut RigidBody,
b: &mut RigidBody,
manifold: &ContactManifold,
)Resolve a contact manifold by applying impulses to both bodies.