Module joints

Module joints 

3D Physics joints, rigid bodies, collision detection, broadphase, ray casting, impulse resolution, and sleep system.

Components

  • RigidBody — full 3D rigid body with Quat orientation, Mat3 inertia tensor
  • RigidBodyHandle — newtype u32 handle
  • PhysicsWorld3D — arena of RigidBody, gravity, timestep, broadphase, step()
  • CollisionShape — Sphere, Box, Capsule, ConvexHull
  • CollisionDetector — sphere-sphere, sphere-box, box-box (SAT), capsule-capsule
  • Broadphase — sweep-and-prune on X-axis
  • RayCast — ray vs shape intersection
  • ImpulseResolver — sequential impulse with friction cone, restitution, warm-start
  • SleepSystem — kinetic energy threshold, sleep counter, island wake propagation

Structs

Broadphase
Sweep-and-prune broadphase on the X axis with insertion sort.
BroadphaseEntry
AABB entry for broadphase sweep-and-prune.
CharacterController
CollisionDetector
Narrow-phase collision detection.
ContactManifold3D
Result of collision detection between two bodies.
ContactPoint
A single contact point in a collision manifold.
ImpulseResolver
Sequential impulse resolver with friction cone projection, restitution, and warm-starting.
Joint
JointAnchor
JointImpulse
JointLimits
JointSolver
Positional constraint solver using Sequential Impulses.
PhysicsWorld3D
The 3D physics simulation world.
Ragdoll
RagdollBone
Ray
Ray for intersection tests.
RayCast
Ray intersection routines.
RayHit
Result of a ray-cast hit.
RigidBody
Full 3D rigid body.
RigidBodyHandle
Opaque handle into a PhysicsWorld3D body arena.
SleepSystem
Manages sleeping bodies to skip expensive simulation when at rest.

Enums

CollisionShape
Collision shapes supported by the physics engine.
JointType
SleepState