pub struct AffixPool { /* private fields */ }Expand description
Weighted pool of affixes for rolling item modifiers.
Implementations
Sourceimpl AffixPool
impl AffixPool
Sourcepub fn default_pool() -> Self
pub fn default_pool() -> Self
Create the built-in pool with 60+ affixes.
Sourcepub fn roll_prefix(&self, item_level: u32, rng: &mut Rng) -> Option<&Affix>
pub fn roll_prefix(&self, item_level: u32, rng: &mut Rng) -> Option<&Affix>
Roll a random prefix for the given item level.
Sourcepub fn roll_suffix(&self, item_level: u32, rng: &mut Rng) -> Option<&Affix>
pub fn roll_suffix(&self, item_level: u32, rng: &mut Rng) -> Option<&Affix>
Roll a random suffix for the given item level.
pub fn prefix_count(&self) -> usize
pub fn suffix_count(&self) -> usize