pub fn apply_gate(
register: &QuantumRegister,
gate: &QuantumGate,
target_qubits: &[usize],
) -> QuantumRegisterExpand description
Apply a gate to specific target qubits in a register.
pub fn apply_gate(
register: &QuantumRegister,
gate: &QuantumGate,
target_qubits: &[usize],
) -> QuantumRegisterApply a gate to specific target qubits in a register.