pub fn partial_trace(
state: &TwoQubitState,
trace_out: usize,
) -> DensityMatrix2x2Expand description
Partial trace: trace out one qubit to get the density matrix of the other.
pub fn partial_trace(
state: &TwoQubitState,
trace_out: usize,
) -> DensityMatrix2x2Partial trace: trace out one qubit to get the density matrix of the other.