energy_eigenvalues

Function energy_eigenvalues 

pub fn energy_eigenvalues(
    potential: &[f64],
    n_states: usize,
    dx: f64,
    mass: f64,
    hbar: f64,
) -> Vec<f64>
Compute energy eigenvalues using the shooting method for the time-independent Schrodinger equation with the given potential on a uniform grid.