pub struct GravTimeDilationField {
pub width: usize,
pub height: usize,
pub center: Vec2,
pub rs: f64,
pub factors: Vec<f64>,
pub cell_size: f32,
}Expand description
2D grid of time dilation factors around a mass.
Fields
width: usizeheight: usizecenter: Vec2rs: f64factors: Vec<f64>cell_size: f32Implementations
Sourceimpl GravTimeDilationField
impl GravTimeDilationField
pub fn new( width: usize, height: usize, center: Vec2, mass: f64, c: f64, g_const: f64, cell_size: f32, ) -> Self
Sourcepub fn get(&self, ix: usize, iy: usize) -> f64
pub fn get(&self, ix: usize, iy: usize) -> f64
Get the time dilation factor at a grid position.
Sourcepub fn sample(&self, pos: Vec2) -> f64
pub fn sample(&self, pos: Vec2) -> f64
Sample the time dilation factor at an arbitrary position.
Sourcepub fn schwarzschild_radius(&self) -> f64
pub fn schwarzschild_radius(&self) -> f64
Get the Schwarzschild radius.
Sourcepub fn radius_for_factor(&self, factor: f64) -> f64
pub fn radius_for_factor(&self, factor: f64) -> f64
Find the radius where time dilation equals a given factor.