pub struct TimeDilationRenderer {
pub c: f64,
pub show_clock_hands: bool,
pub clock_size: f32,
}Expand description
Render clocks with tick rate proportional to proper time rate.
Fields
c: f64show_clock_hands: boolclock_size: f32Implementations
Sourceimpl TimeDilationRenderer
impl TimeDilationRenderer
pub fn new(c: f64) -> Self
Sourcepub fn tick_rate(&self, v: f64) -> f32
pub fn tick_rate(&self, v: f64) -> f32
Compute the apparent tick rate of a clock at velocity v. Returns a fraction of normal tick rate (0 to 1).
Sourcepub fn clock_hand_angle(&self, proper_time: f64) -> f32
pub fn clock_hand_angle(&self, proper_time: f64) -> f32
Compute the clock hand angle for a given proper time. One full rotation = 60 “seconds” of proper time.
Sourcepub fn clock_glyph_data(
&self,
center: Vec2,
proper_time: f64,
) -> (Vec<Vec2>, Vec2)
pub fn clock_glyph_data( &self, center: Vec2, proper_time: f64, ) -> (Vec<Vec2>, Vec2)
Generate glyph data for a clock face at a position. Returns positions for 12 hour markers and the hand endpoint.
Sourcepub fn render_clocks(
&self,
clocks: &[DilatedClock],
positions: &[Vec2],
) -> Vec<(Vec<Vec2>, Vec2)>
pub fn render_clocks( &self, clocks: &[DilatedClock], positions: &[Vec2], ) -> Vec<(Vec<Vec2>, Vec2)>
Render multiple clocks at different velocities.