pub struct SkyModel {
pub params: AtmosphereParams,
}Expand description
Physical sky colour model using single-scattering path integrals.
Fields
params: AtmosphereParamsImplementations
Sourceimpl SkyModel
impl SkyModel
pub fn new(params: AtmosphereParams) -> Self
Sourcepub fn sky_color(&self, ray_dir: Vec3, n_steps: usize) -> Vec3
pub fn sky_color(&self, ray_dir: Vec3, n_steps: usize) -> Vec3
Compute sky colour for a view ray ray_dir (unit vector).
Uses n_steps integration steps along the view ray, and n_light_steps
for each secondary ray toward the sun.
Sourcepub fn sun_transmittance(&self, ray_dir: Vec3) -> Vec3
pub fn sun_transmittance(&self, ray_dir: Vec3) -> Vec3
Compute transmittance along a ray from origin toward the sun.
Sourcepub fn sky_irradiance(&self, normal: Vec3) -> Vec3
pub fn sky_irradiance(&self, normal: Vec3) -> Vec3
Approximate sky irradiance on a surface with the given normal.
Integrates the sky radiance over the upper hemisphere and weights by NdotL. Uses a coarse stratified sample.