pub struct PostFxPipeline {
pub scene_fbo: Framebuffer,
pub scene_color_tex: Texture,
pub scene_emission_tex: Texture,
pub scene_occluder_tex: Texture,
/* private fields */
}Fields
scene_fbo: Framebufferscene_color_tex: Texturescene_emission_tex: Texturescene_occluder_tex: TextureImplementations
Sourceimpl PostFxPipeline
impl PostFxPipeline
pub unsafe fn new( gl: &Context, width: u32, height: u32, render_scale: f32, ) -> Self
Sourcepub fn scene_size(&self) -> (u32, u32)
pub fn scene_size(&self) -> (u32, u32)
The size of the scene targets, which is what the scene passes must set their viewport to.