Module compiler

Module compiler 

Shader graph → GLSL compiler.

Walks the topologically-sorted node list and emits a GLSL fragment shader. Each node type has a corresponding GLSL emission function that receives the names of its input variables and outputs the name of its output variable.

Structs

CompiledShader
The result of compiling a ShaderGraph.
GraphCompiler
UniformDecl

Constants

PASSTHROUGH_VERTEX
SHADER_HELPERS