pub enum BarrierKind {
RenderToShaderRead,
ComputeToRender,
RenderToRender,
ComputeToCompute,
TransferToRead,
FullPipeline,
}Expand description
The kind of GPU barrier inserted between passes.
Variants
RenderToShaderRead
Render target finished writing, will be read as texture.
ComputeToRender
Compute shader finished writing, will be read by render pass.
RenderToRender
Render pass finished, another render pass will write the same target.
ComputeToCompute
Compute finished writing, another compute will read.
TransferToRead
Transfer finished, resource will be read.
FullPipeline
Generic full pipeline barrier.