RenderPass

Struct RenderPass 

pub struct RenderPass {
    pub name: String,
    pub pass_type: PassType,
    pub queue: QueueAffinity,
    pub condition: PassCondition,
    pub resolution: ResolutionScale,
    pub inputs: Vec<ResourceHandle>,
    pub outputs: Vec<ResourceHandle>,
    pub input_names: Vec<String>,
    pub output_names: Vec<String>,
    pub explicit_deps: Vec<String>,
    pub has_side_effects: bool,
    pub tag: Option<String>,
}
A named node in the render graph representing a render pass.

Fields

name: Stringpass_type: PassTypequeue: QueueAffinitycondition: PassConditionresolution: ResolutionScaleinputs: Vec<ResourceHandle>

Resource handles this pass reads.

outputs: Vec<ResourceHandle>

Resource handles this pass writes.

input_names: Vec<String>

Names of input resources (for serialization / debug).

output_names: Vec<String>

Names of output resources.

explicit_deps: Vec<String>

Explicit ordering dependencies (pass names that must run before this).

has_side_effects: bool

Whether this pass has side effects (e.g., writes to swapchain).

tag: Option<String>

User-attached tag for grouping.

Implementations

Source

impl RenderPass

pub fn new(name: &str, pass_type: PassType) -> Self

pub fn with_queue(self, queue: QueueAffinity) -> Self

pub fn with_condition(self, condition: PassCondition) -> Self

pub fn with_resolution(self, scale: ResolutionScale) -> Self

pub fn with_side_effects(self) -> Self

pub fn with_tag(self, tag: &str) -> Self

pub fn add_input(&mut self, handle: ResourceHandle, name: &str)

pub fn add_output(&mut self, handle: ResourceHandle, name: &str)

pub fn depends_on(&mut self, pass_name: &str)

pub fn is_async_compute_candidate(&self) -> bool

True if this pass can potentially run on the async compute queue.