pub fn build_deferred_pipeline(
width: u32,
height: u32,
features: &[&str],
) -> RenderGraphExpand description
Convenience function that builds a complete deferred rendering pipeline with all 12 built-in passes.
pub fn build_deferred_pipeline(
width: u32,
height: u32,
features: &[&str],
) -> RenderGraphConvenience function that builds a complete deferred rendering pipeline with all 12 built-in passes.