pub struct BackupManager { /* private fields */ }Expand description
Rotating local backups — up to 5 per slot.
Implementations
Sourceimpl BackupManager
impl BackupManager
pub fn new() -> Self
Sourcepub fn backup(&mut self, slot_id: u32, data: Vec<u8>, timestamp: u64)
pub fn backup(&mut self, slot_id: u32, data: Vec<u8>, timestamp: u64)
Create a backup of data for the given slot.
Sourcepub fn restore_backup(&self, slot_id: u32, backup_idx: usize) -> Option<Vec<u8>>
pub fn restore_backup(&self, slot_id: u32, backup_idx: usize) -> Option<Vec<u8>>
Restore a backup for a slot by index (0 = oldest).
Sourcepub fn list_backups(&self, slot_id: u32) -> Vec<BackupEntry>
pub fn list_backups(&self, slot_id: u32) -> Vec<BackupEntry>
List all backups for a slot.
Sourcepub fn backup_count(&self, slot_id: u32) -> usize
pub fn backup_count(&self, slot_id: u32) -> usize
Number of backups for a slot.