pub struct MigrationRegistry { /* private fields */ }Expand description
Holds an ordered chain of migrations keyed by source version.
Implementations
Sourceimpl MigrationRegistry
impl MigrationRegistry
pub fn new() -> Self
Sourcepub fn register(&mut self, from_version: u32, f: MigrationFn)
pub fn register(&mut self, from_version: u32, f: MigrationFn)
Register a migration from from_version to from_version + 1.
Sourcepub fn migrate(
&self,
data: &mut SaveData,
from: SchemaVersion,
to: SchemaVersion,
) -> Result<(), String>
pub fn migrate( &self, data: &mut SaveData, from: SchemaVersion, to: SchemaVersion, ) -> Result<(), String>
Run the chain of migrations to bring data from from to to.
Sourcepub fn with_builtin_migrations() -> Self
pub fn with_builtin_migrations() -> Self
Build a registry pre-populated with all 10 built-in migrations (v0→v10).