pub struct ProfileManager { /* private fields */ }Expand description
Manages up to 8 local user profiles.
Implementations
Sourceimpl ProfileManager
impl ProfileManager
pub const MAX_PROFILES: usize = 8
pub fn new() -> Self
Sourcepub fn create(
&mut self,
display_name: impl Into<String>,
timestamp: u64,
) -> Result<u64, String>
pub fn create( &mut self, display_name: impl Into<String>, timestamp: u64, ) -> Result<u64, String>
Create a new profile with the given display name.
Sourcepub fn current(&self) -> Option<&UserProfile>
pub fn current(&self) -> Option<&UserProfile>
Get the currently active profile.
Sourcepub fn current_mut(&mut self) -> Option<&mut UserProfile>
pub fn current_mut(&mut self) -> Option<&mut UserProfile>
Get a mutable reference to the currently active profile.
pub fn list(&self) -> Vec<&UserProfile>
pub fn get_by_id(&self, id: u64) -> Option<&UserProfile>
pub fn get_by_id_mut(&mut self, id: u64) -> Option<&mut UserProfile>
pub fn count(&self) -> usize
Sourcepub fn from_bytes(data: &[u8]) -> Result<Self, String>
pub fn from_bytes(data: &[u8]) -> Result<Self, String>
Deserialise from bytes produced by to_bytes.