pub struct ComponentSerializer { /* private fields */ }Expand description
Registry mapping component type names to their serialize/deserialize functions.
Used by the snapshot system to serialize arbitrary component types by name.
Implementations
Sourceimpl ComponentSerializer
impl ComponentSerializer
pub fn new() -> Self
Sourcepub fn register<T: Serialize + Deserialize + Any + Send + Sync + 'static>(
&mut self,
name: impl Into<String>,
)
pub fn register<T: Serialize + Deserialize + Any + Send + Sync + 'static>( &mut self, name: impl Into<String>, )
Register a component type T under name.
Sourcepub unsafe fn serialize_any(
&self,
type_id: TypeId,
ptr: *const u8,
) -> Option<SerializedValue>
pub unsafe fn serialize_any( &self, type_id: TypeId, ptr: *const u8, ) -> Option<SerializedValue>
Serialize a component by TypeId, given a raw pointer to its data.
Safety
ptr must point to a valid value of the type identified by type_id.
Sourcepub fn deserialize_any(
&self,
name: &str,
v: &SerializedValue,
) -> Option<Box<dyn Any + Send + Sync>>
pub fn deserialize_any( &self, name: &str, v: &SerializedValue, ) -> Option<Box<dyn Any + Send + Sync>>
Deserialize a component by name.
Sourcepub fn registered_names(&self) -> impl Iterator<Item = &str>
pub fn registered_names(&self) -> impl Iterator<Item = &str>
All registered component names.