pub struct UpvalDesc {
pub name: String,
pub in_stack: bool,
pub index: u16,
}Expand description
How an upvalue is captured by a closure.
Fields
name: Stringin_stack: boolIf true, the upvalue is a local slot in the immediately enclosing scope; otherwise it is an upvalue of the enclosing function.
index: u16Trait Implementations