pub struct BrownianBridge {
pub start: f64,
pub end: f64,
pub steps: usize,
}Expand description
Brownian bridge: a Brownian motion conditioned to reach a specified endpoint.
B(t) = (1 - t/T)*start + (t/T)*end + W(t) - (t/T)*W(T) which is implemented by generating a free Wiener path then pinning it.
Fields
start: f64Starting value.
end: f64Ending value (the bridge is conditioned to hit this).
steps: usizeNumber of discrete steps.
Implementations