pub fn percolates(grid: &PercolationGrid) -> boolExpand description
Check if the grid percolates (there exists a cluster spanning from top to bottom).
pub fn percolates(grid: &PercolationGrid) -> boolCheck if the grid percolates (there exists a cluster spanning from top to bottom).