pub struct Deformation {
pub mode: DeformationMode,
pub weight: f32,
pub active: bool,
pub falloff: FalloffFunction,
pub falloff_center: Vec3,
pub falloff_radius: f32,
}Expand description
A single deformation with its parameters and time influence.
Fields
mode: DeformationModeweight: f32Weight/intensity of this deformation (0 = off, 1 = full).
active: boolWhether the deformation is active.
falloff: FalloffFunctionFalloff function: distance from center of effect -> weight multiplier.
falloff_center: Vec3Center of the falloff region (in local space).
falloff_radius: f32Radius of the falloff region.
Implementations
Sourceimpl Deformation
impl Deformation
Sourcepub fn new(mode: DeformationMode) -> Self
pub fn new(mode: DeformationMode) -> Self
Create a new deformation at full weight with no falloff.
Sourcepub fn with_weight(self, weight: f32) -> Self
pub fn with_weight(self, weight: f32) -> Self
Set the weight of this deformation.
Sourcepub fn with_falloff(
self,
center: Vec3,
radius: f32,
falloff: FalloffFunction,
) -> Self
pub fn with_falloff( self, center: Vec3, radius: f32, falloff: FalloffFunction, ) -> Self
Set a spherical falloff region.