Module cone_trace

Module cone_trace 

Structs

ConeDistribution
Cone distribution presets.
ConeTraceConfig
Configuration for cone tracing.
ConeTraceResult
Result from a cone trace.

Constants

CONE_TRACE_FRAG_SRC
Embedded fragment shader for GPU cone tracing.

Functions

ambient_occlusion
Compute ambient occlusion by tracing wide cones above the surface.
diffuse_gi
Compute diffuse global illumination by tracing multiple cones in a hemisphere.
hemisphere_cones
Generate cone directions distributed over a hemisphere.
soft_shadows
Compute soft shadows by tracing a cone toward a light.
specular_gi
Compute specular global illumination using a single narrow cone in the reflection direction.
trace_cone
Trace a cone through the octree.