pub fn diffuse_gi(
octree: &SparseVoxelOctree,
position: Vec3,
normal: Vec3,
config: &ConeTraceConfig,
) -> Vec3Expand description
Compute diffuse global illumination by tracing multiple cones in a hemisphere.
pub fn diffuse_gi(
octree: &SparseVoxelOctree,
position: Vec3,
normal: Vec3,
config: &ConeTraceConfig,
) -> Vec3Compute diffuse global illumination by tracing multiple cones in a hemisphere.