Module heightmap

Module heightmap 

Heightmap generation, erosion, post-processing, and analysis.

This module provides multiple terrain generation algorithms, erosion simulations, post-processing filters, and analytical tools for working with 2D height fields used as terrain data.

Structs

AdvancedHydraulicErosion
Advanced hydraulic erosion with explicit water table tracking.
CompositeLayer
A single layer in a compositor.
DiamondSquare
Generates terrain using the Diamond-Square (Midpoint Displacement) algorithm.
DisplacementWarp
Warp (distort) a heightmap using a displacement field.
FractalNoise
Generates terrain using layered (fractal) gradient noise.
GradientNoisePublic
Minimal self-contained 2D value/gradient noise.
HeightMap
A 2D grid of f32 height values.
HeightMapCompositor
Composites multiple heightmaps using layered blending operations.
HeightMapFilter
Operations that work in gradient/frequency domain.
HydraulicErosion
Simulates water-driven erosion.
PerlinTerrain
Multi-octave Perlin terrain with additional continental shaping.
Rng
TectonicSimulation
Extended tectonic simulation with plate movement and collision.
ThermalErosion
Simulates thermal weathering (slope-driven material movement).
VoronoiPlates
Simulates tectonic plates using Voronoi diagrams.
WindErosion
Simulates aeolian (wind-driven) erosion and deposition.
WorleyTerrain
Generates terrain using Worley (cellular / Voronoi) noise. Produces cracked-earth, rocky, or cell-structured terrain.

Enums

CompositeBlendMode
How a layer blends with layers below it.