pub struct ChunkGrid {
pub origin: ChunkCoord,
pub width: i32,
pub height: i32,
}Expand description
A 2D grid of chunk coordinates within a rectangular region.
Fields
origin: ChunkCoordwidth: i32height: i32Implementations
Sourceimpl ChunkGrid
impl ChunkGrid
Sourcepub fn around(center: ChunkCoord, half_extent: i32) -> Self
pub fn around(center: ChunkCoord, half_extent: i32) -> Self
Create a grid of chunks centred on center with given half-extent.
Sourcepub fn iter(&self) -> impl Iterator<Item = ChunkCoord> + '_
pub fn iter(&self) -> impl Iterator<Item = ChunkCoord> + '_
Iterate all coords in the grid.
Sourcepub fn contains(&self, c: ChunkCoord) -> bool
pub fn contains(&self, c: ChunkCoord) -> bool
Test if a coord is within this grid.
Sourcepub fn at(&self, col: i32, row: i32) -> ChunkCoord
pub fn at(&self, col: i32, row: i32) -> ChunkCoord
Convert a grid-relative (col, row) to ChunkCoord.
Sourcepub fn sorted_by_distance(&self, center: ChunkCoord) -> Vec<ChunkCoord>
pub fn sorted_by_distance(&self, center: ChunkCoord) -> Vec<ChunkCoord>
Coords sorted by distance to center.