pub struct WorldMap {
pub height_overview: HeightMap,
pub biome_overview: Vec<u8>,
pub resolution: usize,
pub world_size_chunks: usize,
}Expand description
Low-resolution overview map of the entire world, used for minimap and LOD hints.
Fields
height_overview: HeightMapLow-resolution height overview.
biome_overview: Vec<u8>Biome overview (compressed to u8 per cell).
resolution: usizeOverview resolution.
world_size_chunks: usizeWorld size in chunks.
Implementations
Sourceimpl WorldMap
impl WorldMap
Sourcepub fn generate(
world_size_chunks: usize,
resolution: usize,
config: &TerrainConfig,
) -> Self
pub fn generate( world_size_chunks: usize, resolution: usize, config: &TerrainConfig, ) -> Self
Generate a world map by sampling the global noise function.
Sourcepub fn sample_height(&self, nx: f32, ny: f32) -> f32
pub fn sample_height(&self, nx: f32, ny: f32) -> f32
Sample height at normalized world position (0..1).
Sourcepub fn sample_biome(&self, nx: f32, ny: f32) -> BiomeType
pub fn sample_biome(&self, nx: f32, ny: f32) -> BiomeType
Get biome at normalized world position.
Sourcepub fn chunk_to_normalized(&self, coord: ChunkCoord) -> (f32, f32)
pub fn chunk_to_normalized(&self, coord: ChunkCoord) -> (f32, f32)
Convert chunk coord to normalized world position.