VegetationSystem

Struct VegetationSystem 

pub struct VegetationSystem {
    pub instances: Vec<VegetationInstance>,
    pub grass_field: GrassField,
    pub rock_clusters: Vec<RockCluster>,
    pub wind_vector: Vec2,
    pub time: f32,
}
Top-level manager for all vegetation instances.

Fields

instances: Vec<VegetationInstance>grass_field: GrassFieldrock_clusters: Vec<RockCluster>wind_vector: Vec2time: f32

Implementations

Source

impl VegetationSystem

pub fn new() -> Self

pub fn generate( heightmap: &HeightMap, biome_map: &BiomeMap, density_scale: f32, seed: u64, ) -> Self

Generate all vegetation from a heightmap and biome map.

pub fn update_lod(&mut self, camera_pos: Vec3)

Update LOD levels for all instances based on camera position.

pub fn frustum_cull(&mut self, planes: &[(Vec3, f32); 6])

Frustum cull instances. planes is 6 plane normal+distance pairs.

pub fn apply_season(&mut self, month: u32)

Apply seasonal variation to all instances.

pub fn update(&mut self, dt: f32, wind: Vec2)

Update wind simulation for the given time step.

pub fn visible_count(&self) -> usize

Count visible instances.

pub fn instances_at_lod( &self, lod: u8, ) -> impl Iterator<Item = &VegetationInstance>

Get all visible instances at a given LOD level.