pub struct TimelinePlayer {
pub timeline: Timeline,
pub time: f32,
pub state: PlaybackState,
/* private fields */
}Expand description
Drives a Timeline forward in time and dispatches actions.
Fields
timeline: Timelinetime: f32state: PlaybackStateImplementations
Sourceimpl TimelinePlayer
impl TimelinePlayer
pub fn new(timeline: Timeline) -> Self
pub fn play(&mut self)
pub fn pause(&mut self)
pub fn resume(&mut self)
pub fn stop(&mut self)
pub fn seek(&mut self, time: f32)
pub fn is_playing(&self) -> bool
pub fn is_finished(&self) -> bool
Sourcepub fn register_callback(
&mut self,
name: impl Into<String>,
f: impl Fn(&HashMap<String, String>) + Send + Sync + 'static,
)
pub fn register_callback( &mut self, name: impl Into<String>, f: impl Fn(&HashMap<String, String>) + Send + Sync + 'static, )
Register a named callback.
Sourcepub fn tick(&mut self, dt: f32) -> Vec<TimelineAction>
pub fn tick(&mut self, dt: f32) -> Vec<TimelineAction>
Advance the timeline by dt seconds and fire pending cues.
Returns a list of actions that fired this tick.
pub fn get_flag(&self, name: &str) -> bool
pub fn set_flag(&mut self, name: impl Into<String>, value: bool)