pub fn classify_surface(chi: i32, orientable: bool) -> SurfaceTypeExpand description
Classify a closed surface from its Euler characteristic and orientability.
pub fn classify_surface(chi: i32, orientable: bool) -> SurfaceTypeClassify a closed surface from its Euler characteristic and orientability.