pub struct KleinDisk;Expand description
The Klein (Beltrami-Klein) disk model of hyperbolic geometry. Geodesics are straight lines (chords) but angles are distorted.
Implementations
Sourceimpl KleinDisk
impl KleinDisk
Sourcepub fn to_klein(&self, pos: Vec2) -> Vec2
pub fn to_klein(&self, pos: Vec2) -> Vec2
Convert a world position to Klein disk coordinates. Points map into the unit disk.
Sourcepub fn from_klein(&self, pos: Vec2) -> Vec2
pub fn from_klein(&self, pos: Vec2) -> Vec2
Convert Klein disk coordinates back to world position.
Sourcepub fn poincare_to_klein(pos: Vec2) -> Vec2
pub fn poincare_to_klein(pos: Vec2) -> Vec2
Convert a Poincare disk point to Klein disk point. K = 2P / (1 + |P|^2)
Sourcepub fn klein_to_poincare(pos: Vec2) -> Vec2
pub fn klein_to_poincare(pos: Vec2) -> Vec2
Convert a Klein disk point to Poincare disk point. P = K / (1 + sqrt(1 - |K|^2))