pub struct SphericalCoord {
pub theta: f32,
pub phi: f32,
}Expand description
Spherical coordinate with polar angle theta (from +Z) and azimuthal angle phi (from +X in XY).
Fields
theta: f32Polar angle from the positive Z axis, in [0, PI]
phi: f32Azimuthal angle from the positive X axis in the XY plane, in [0, 2*PI)
Implementations