pub struct KeyframeTrack<T: Lerp + Clone + Debug> {
pub frames: Vec<Keyframe<T>>,
pub extrapolate: ExtrapolateMode,
}Expand description
An ordered list of keyframes with time-based interpolation.
Automatically sorts keyframes by time on construction and rebuilds segment lookup on insertion.
Fields
frames: Vec<Keyframe<T>>extrapolate: ExtrapolateModeImplementations
Sourceimpl<T: Lerp + Clone + Debug> KeyframeTrack<T>
impl<T: Lerp + Clone + Debug> KeyframeTrack<T>
pub fn new(extrapolate: ExtrapolateMode) -> Self
Sourcepub fn from_keyframes(
frames: Vec<Keyframe<T>>,
extrapolate: ExtrapolateMode,
) -> Self
pub fn from_keyframes( frames: Vec<Keyframe<T>>, extrapolate: ExtrapolateMode, ) -> Self
Create a track from a list of keyframes, sorted by time.
pub fn is_empty(&self) -> bool
Sourcepub fn start_time(&self) -> f32
pub fn start_time(&self) -> f32
Start time of the track.