pub enum SpawnMode {
Continuous,
Burst {
count: u32,
},
BurstOverTime {
count: u32,
duration: f32,
emitted: u32,
},
}Expand description
Whether the emitter emits continuously or fires a one-shot burst.
Variants
Continuous
Emit continuously as long as the emitter is active.
Burst
Fire exactly count particles at once then become inactive.
BurstOverTime
Fire count particles spread over duration seconds then stop.