pub struct ForceComposite {
pub fields: Vec<ForceField>,
pub blend_mode: ForceBlendMode,
pub global_scale: f32,
}Expand description
A group of force fields evaluated together with a blend mode.
Fields
fields: Vec<ForceField>blend_mode: ForceBlendModeglobal_scale: f32Implementations
Sourceimpl ForceComposite
impl ForceComposite
pub fn new() -> Self
pub fn with_blend(self, mode: ForceBlendMode) -> Self
pub fn add(&mut self, field: ForceField)
pub fn remove(&mut self, id: ForceFieldId)
pub fn get_mut(&mut self, id: ForceFieldId) -> Option<&mut ForceField>
pub fn tick(&mut self, dt: f32)
Sourcepub fn net_acceleration(&self, particle: &Particle) -> Vec3
pub fn net_acceleration(&self, particle: &Particle) -> Vec3
Compute the net acceleration for a particle from all fields.
Sourcepub fn apply_to_particle(&self, particle: &mut Particle)
pub fn apply_to_particle(&self, particle: &mut Particle)
Apply all forces to a particle, accumulating into its acceleration.
Sourcepub fn apply_and_cull(&self, particles: &mut Vec<Particle>)
pub fn apply_and_cull(&self, particles: &mut Vec<Particle>)
Apply forces to a whole slice of particles and remove absorbed ones.