pub struct ForceField {
pub id: ForceFieldId,
pub enabled: bool,
pub strength_scale: f32,
pub tag_mask: TagMask,
pub kind: ForceFieldKind,
pub priority: i32,
}Expand description
A single force field entry in the world, combining a field type with metadata.
Fields
id: ForceFieldIdenabled: boolstrength_scale: f32tag_mask: TagMaskkind: ForceFieldKindpriority: i32Implementations
Sourceimpl ForceField
impl ForceField
pub fn new(id: ForceFieldId, kind: ForceFieldKind) -> Self
pub fn with_tag_mask(self, mask: TagMask) -> Self
pub fn with_scale(self, s: f32) -> Self
pub fn with_priority(self, p: i32) -> Self
pub fn disabled(self) -> Self
Sourcepub fn apply(&self, particle: &Particle) -> Vec3
pub fn apply(&self, particle: &Particle) -> Vec3
Compute the acceleration this field imparts on a particle (per unit mass, i.e. force/mass).
pub fn tick(&mut self, dt: f32)
pub fn marks_for_death(&self, particle: &Particle) -> bool