pub struct ForceFieldWorld {
pub composite: ForceComposite,
pub gravity: Vec3,
pub gravity_enabled: bool,
/* private fields */
}Expand description
Global registry for all force fields active in the world.
Fields
composite: ForceCompositegravity: Vec3Gravity constant applied to all particles unless overridden.
gravity_enabled: boolImplementations
Sourceimpl ForceFieldWorld
impl ForceFieldWorld
pub fn new() -> Self
pub fn add_gravity_well( &mut self, pos: Vec3, strength: f32, radius: f32, ) -> ForceFieldId
pub fn add_vortex( &mut self, pos: Vec3, axis: Vec3, strength: f32, radius: f32, ) -> ForceFieldId
pub fn add_turbulence(&mut self, strength: f32, frequency: f32) -> ForceFieldId
pub fn add_wind(&mut self, direction: Vec3, speed: f32) -> ForceFieldId
pub fn add_attractor( &mut self, pos: Vec3, strength: f32, radius: f32, ) -> ForceFieldId
pub fn add_repulsor( &mut self, pos: Vec3, strength: f32, radius: f32, ) -> ForceFieldId
pub fn add_drag(&mut self, coefficient: f32) -> ForceFieldId
pub fn add_buoyancy(&mut self, gravity: f32) -> ForceFieldId
pub fn add_field(&mut self, kind: ForceFieldKind) -> ForceFieldId
pub fn remove_field(&mut self, id: ForceFieldId)
pub fn get_mut(&mut self, id: ForceFieldId) -> Option<&mut ForceField>
pub fn tick(&mut self, dt: f32)
pub fn apply_to_particles(&self, particles: &mut Vec<Particle>)
pub fn field_count(&self) -> usize
Sourceimpl ForceFieldWorld
impl ForceFieldWorld
Sourcepub fn debug_sample(&self, pos: Vec3) -> ForceDebugSample
pub fn debug_sample(&self, pos: Vec3) -> ForceDebugSample
Sample the force at a given position with a synthetic particle.