pub struct WindField {
pub grid_w: usize,
pub grid_h: usize,
pub grid_d: usize,
pub resolution: f32,
pub layer_height: f32,
pub data: Vec<WindVector>,
}Expand description
3-D wind field stored as a grid of WindVector.
Fields
grid_w: usizegrid_h: usizegrid_d: usizeresolution: f32layer_height: f32data: Vec<WindVector>Implementations
Sourceimpl WindField
impl WindField
pub fn new( w: usize, h: usize, d: usize, resolution: f32, layer_height: f32, ) -> Self
pub fn set(&mut self, x: usize, y: usize, z: usize, wv: WindVector)
Sourcepub fn sample_world(&self, wx: f32, wy: f32, wz: f32) -> WindVector
pub fn sample_world(&self, wx: f32, wy: f32, wz: f32) -> WindVector
Sample wind at world-space position using trilinear interpolation.
Sourcepub fn fill_from_layers(&mut self, layers: &[AtmosphericLayer])
pub fn fill_from_layers(&mut self, layers: &[AtmosphericLayer])
Fill the entire field with a base directional wind that varies by layer.