pub struct ScreenshotCapture { /* private fields */ }Expand description
Captures frames from a live renderer.
Implementations
Sourceimpl ScreenshotCapture
impl ScreenshotCapture
pub fn new(width: u32, height: u32) -> Self
Sourcepub fn request_capture(&mut self)
pub fn request_capture(&mut self)
Request a capture on the next frame.
Sourcepub fn should_capture(&mut self) -> bool
pub fn should_capture(&mut self) -> bool
Check if a capture was requested and consume the flag.
Sourcepub fn store_capture(&mut self, pixels: Vec<u8>)
pub fn store_capture(&mut self, pixels: Vec<u8>)
Store captured pixel data.
Sourcepub fn capture_next_frame(
&mut self,
renderer: &mut HeadlessRenderer,
scene: &SceneDesc,
camera: &CameraDesc,
) -> Vec<u8> ⓘ
pub fn capture_next_frame( &mut self, renderer: &mut HeadlessRenderer, scene: &SceneDesc, camera: &CameraDesc, ) -> Vec<u8> ⓘ
Capture the next frame from the given headless renderer.
Sourcepub fn last_capture(&self) -> Option<&[u8]>
pub fn last_capture(&self) -> Option<&[u8]>
Get the last captured pixels.
Sourcepub fn has_capture(&self) -> bool
pub fn has_capture(&self) -> bool
Whether we have a stored capture.