Adaptive quality management: auto-detect hardware capability, dynamically adjust rendering quality to maintain a target frame rate, and benchmarking.
Structs
- Benchmark
Result - Result of a GPU benchmark run.
- Quality
Manager - Dynamically adjusts quality level to maintain a target frame rate.
- Quality
Profile - Concrete rendering settings for a quality level.
Enums
- Quality
Level - Discrete quality tier.
Functions
- auto_
detect_ quality - Choose a quality level based on hardware capabilities.
- run_
benchmark - Run a simple benchmark on the given renderer for
duration_secs. Because we have no real GPU, this measures CPU-side overhead of the software backend.