Module goap

Module goap 

Goal-Oriented Action Planning (GOAP).

Each agent has a world state (map of bool conditions), a goal state, and a set of actions with preconditions and effects. The planner uses A* to find the cheapest sequence of actions that transforms current state into goal state.

Structs

GoapAction
An action that can be taken by a GOAP agent.
GoapAgent
A runtime GOAP agent that re-plans when its goal or state changes.
GoapPlanner
Plans a sequence of actions to reach goal state from current state.
WorldState
A set of named boolean conditions describing world state.

Enums

ActionResult

Functions

guard_actions
Patrol and investigation actions.
melee_combat_actions
Standard combat actions for a melee fighter.