RootMotion

Struct RootMotion 

pub struct RootMotion {
    pub delta_translation: Vec3,
    pub delta_rotation: Quat,
}
Root motion extracted from a clip’s root bone.

Instead of moving the root bone in the pose, the delta is handed off to the game’s character controller so it can be applied to the entity’s world transform.

Fields

delta_translation: Vec3delta_rotation: Quat

Implementations

Source

impl RootMotion

pub fn zero() -> Self

pub fn extract_root_motion( clip: &AnimationClip, current_time: f32, dt: f32, ) -> Self

Compute the root-motion delta between two times in a clip.

dt seconds of motion are sampled from the clip’s first channel that targets the root bone (BoneId 0) translation and rotation.

pub fn accumulate(&self, other: &RootMotion) -> RootMotion

Accumulate another root motion delta.

pub fn is_zero(&self) -> bool