pub struct LookAtSolver;Expand description
Rotates a joint to aim at a target (look-at constraint).
Used for head/eye tracking, weapon aiming, etc.
Implementations
Sourceimpl LookAtSolver
impl LookAtSolver
Sourcepub fn look_at_quat(
eye_position: Vec3,
target: Vec3,
forward: Vec3,
up: Vec3,
) -> Quat
pub fn look_at_quat( eye_position: Vec3, target: Vec3, forward: Vec3, up: Vec3, ) -> Quat
Compute the rotation quaternion that rotates forward to point at target
from eye_position, with an up hint vector.