pub trait Asset:
Send
+ Sync
+ 'static { }Expand description
Marker trait for any type that can be stored as an asset.
Implementors must be Send + Sync + 'static so they can be shared
across threads and stored in the global registry without lifetime issues.
Example
use proof_engine::asset::Asset;
struct MyData { value: u32 }
impl Asset for MyData {}Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".