pub struct ComboTracker {
pub database: ComboDatabase,
}Expand description
High-level tracker that wraps the combo database and per-entity combo state.
Fields
database: ComboDatabaseImplementations
Sourceimpl ComboTracker
impl ComboTracker
pub fn new(database: ComboDatabase) -> Self
Sourcepub fn try_start(&self, state: &mut ComboState) -> Option<&Combo>
pub fn try_start(&self, state: &mut ComboState) -> Option<&Combo>
Try to start a combo from the current input buffer state.
Sourcepub fn active_combo<'a>(&'a self, state: &ComboState) -> Option<&'a Combo>
pub fn active_combo<'a>(&'a self, state: &ComboState) -> Option<&'a Combo>
Get the current active combo (if any).
Sourcepub fn current_hit<'a>(&'a self, state: &ComboState) -> Option<&'a ComboHit>
pub fn current_hit<'a>(&'a self, state: &ComboState) -> Option<&'a ComboHit>
Get the current hit in the active combo.