pub struct SpecializationConstant {
pub name: String,
pub value: String,
pub id: u32,
}Expand description
A specialization constant that can be set at compile time.
In OpenGL this is simulated via #define injection.
Fields
name: StringConstant name (becomes a #define).
value: StringValue as string (will be injected as-is).
id: u32Constant ID (for Vulkan compatibility tracking).
Implementations
Sourceimpl SpecializationConstant
impl SpecializationConstant
Sourcepub fn int(name: &str, id: u32, value: i32) -> Self
pub fn int(name: &str, id: u32, value: i32) -> Self
Create a new integer specialization constant.
Sourcepub fn uint(name: &str, id: u32, value: u32) -> Self
pub fn uint(name: &str, id: u32, value: u32) -> Self
Create a new unsigned integer specialization constant.
Sourcepub fn float(name: &str, id: u32, value: f32) -> Self
pub fn float(name: &str, id: u32, value: f32) -> Self
Create a new float specialization constant.
Sourcepub fn boolean(name: &str, id: u32, value: bool) -> Self
pub fn boolean(name: &str, id: u32, value: bool) -> Self
Create a boolean specialization constant (0 or 1).
Sourcepub fn apply(&self, source: &mut ShaderSource)
pub fn apply(&self, source: &mut ShaderSource)
Apply this constant to a shader source as a define.