CpuFallback

Struct CpuFallback 

pub struct CpuFallback { /* private fields */ }
CPU fallback that implements the same interface as GPU compute for hardware without compute shader support.

Each “kernel” is implemented as a Rust function operating on CPU-side arrays. This allows the engine to function on older hardware, albeit at lower performance.

Implementations

Source

impl CpuFallback

pub fn new() -> Self

Create a new CPU fallback.

pub fn activate(&mut self)

Activate the fallback (use when compute shaders are unavailable).

pub fn deactivate(&mut self)

Deactivate (revert to GPU).

pub fn is_active(&self) -> bool

Whether the fallback is currently active.

pub fn particle_integrate( &mut self, positions: &mut [[f32; 4]], velocities: &mut [[f32; 4]], params: &ParticleIntegrateParams, )

CPU particle integration (matches particle_integrate kernel).

pub fn lorenz_step( &mut self, points: &mut [[f32; 3]], sigma: f32, rho: f32, beta: f32, dt: f32, )

CPU Lorenz attractor integration.

pub fn mandelbrot_iterate( &mut self, z_re: &mut [f32], z_im: &mut [f32], c_re: &[f32], c_im: &[f32], iterations: &mut [u32], max_iter: u32, )

CPU Mandelbrot iteration.

pub fn julia_iterate( &mut self, z_re: &mut [f32], z_im: &mut [f32], c_re: f32, c_im: f32, iterations: &mut [u32], max_iter: u32, )

CPU Julia set iteration.

pub fn prefix_sum_exclusive(&mut self, data: &mut [u32])

CPU prefix sum (exclusive scan).

pub fn prefix_sum_inclusive(&mut self, data: &mut [u32])

CPU prefix sum (inclusive scan).

pub fn radix_sort(&mut self, keys: &mut [u32], values: &mut [u32])

CPU radix sort (key-value pairs, ascending).

pub fn frustum_cull( &mut self, positions: &[[f32; 3]], radii: &[f32], planes: &[[f32; 4]; 6], ) -> Vec<usize>

CPU frustum culling.

pub fn skin_vertices( &mut self, positions: &[[f32; 3]], normals: &[[f32; 3]], bone_indices: &[[u32; 4]], bone_weights: &[[f32; 4]], bone_matrices: &[[f32; 16]], inv_bind_matrices: &[[f32; 16]], out_positions: &mut [[f32; 3]], out_normals: &mut [[f32; 3]], )

CPU skinning: transform vertices by bone matrices.

pub fn fluid_diffuse( &mut self, grid: &mut [f32], scratch: &mut [f32], width: usize, height: usize, diffusion_rate: f32, dt: f32, iterations: usize, )

CPU fluid diffusion (Jacobi iteration).

pub fn histogram_equalize( &mut self, data: &mut [f32], bin_count: usize, min_val: f32, max_val: f32, )

CPU histogram equalization.

pub fn last_execution_us(&self, name: &str) -> Option<u64>

Get the last execution time for a named kernel, in microseconds.

pub fn summary(&self) -> String

Summary of all kernel execution times.