pub struct TradeWindow {
pub id: u64,
pub player_a: String,
pub player_b: String,
pub offer_a: Vec<(String, u32)>,
pub offer_b: Vec<(String, u32)>,
pub gold_a: u64,
pub gold_b: u64,
pub confirmed_a: bool,
pub confirmed_b: bool,
pub completed: bool,
pub cancelled: bool,
}Expand description
State of an active trade negotiation between two players.
Fields
id: u64player_a: Stringplayer_b: Stringoffer_a: Vec<(String, u32)>Items offered by player A (item_id, quantity).
offer_b: Vec<(String, u32)>Items offered by player B (item_id, quantity).
gold_a: u64Additional gold offered by A (in copper; can be 0).
gold_b: u64Additional gold offered by B (in copper; can be 0).
confirmed_a: boolconfirmed_b: boolcompleted: boolWhether the trade was executed (items already swapped).
cancelled: boolWhether the trade was cancelled.
Implementations
Sourceimpl TradeWindow
impl TradeWindow
pub fn new(id: u64, player_a: &str, player_b: &str) -> Self
Sourcepub fn add_item_a(&mut self, item_id: impl Into<String>, quantity: u32)
pub fn add_item_a(&mut self, item_id: impl Into<String>, quantity: u32)
Add an item to player A’s offer. Resets both confirmations.
Sourcepub fn add_item_b(&mut self, item_id: impl Into<String>, quantity: u32)
pub fn add_item_b(&mut self, item_id: impl Into<String>, quantity: u32)
Add an item to player B’s offer. Resets both confirmations.
Sourcepub fn set_gold_a(&mut self, copper: u64)
pub fn set_gold_a(&mut self, copper: u64)
Set gold offer for player A. Resets both confirmations.
Sourcepub fn set_gold_b(&mut self, copper: u64)
pub fn set_gold_b(&mut self, copper: u64)
Set gold offer for player B. Resets both confirmations.
Sourcepub fn remove_item_a(&mut self, index: usize)
pub fn remove_item_a(&mut self, index: usize)
Remove an item from player A’s offer by index.
Sourcepub fn remove_item_b(&mut self, index: usize)
pub fn remove_item_b(&mut self, index: usize)
Remove an item from player B’s offer by index.
Sourcepub fn unconfirm(&mut self, player_id: &str)
pub fn unconfirm(&mut self, player_id: &str)
Un-confirm (e.g. when the other player changes their offer).
Sourcepub fn execute(
&mut self,
inventory_a: &mut HashMap<String, u32>,
inventory_b: &mut HashMap<String, u32>,
currency_a: &mut Currency,
currency_b: &mut Currency,
) -> Result<(), String>
pub fn execute( &mut self, inventory_a: &mut HashMap<String, u32>, inventory_b: &mut HashMap<String, u32>, currency_a: &mut Currency, currency_b: &mut Currency, ) -> Result<(), String>
Execute the trade, validating both parties have sufficient funds and inventory.
inventory_a and inventory_b are item_id -> quantity maps for each player.
currency_a and currency_b are each player’s wallet (modified in place).
Returns Ok(()) if the trade succeeded, Err with reason otherwise.