pub struct FrameProfiler { /* private fields */ }Expand description
Rolling-window CPU frame profiler.
Spans are identified by string name. Begin/end calls must be paired. Stats are available as averages, min, max, and last value.
Implementations
Sourceimpl FrameProfiler
impl FrameProfiler
Sourcepub fn new(window_frames: usize) -> Self
pub fn new(window_frames: usize) -> Self
Create a profiler with a rolling window of window_frames frames.
Sourcepub fn begin_frame(&mut self)
pub fn begin_frame(&mut self)
Mark the start of a new frame (measures total frame time under “frame”).
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Total frame count since creation.
Sourcepub fn format_report(&self) -> String
pub fn format_report(&self) -> String
Format the profiler report as a multi-line string.
Sourcepub fn over_budget(&self, budget_ms: f32) -> bool
pub fn over_budget(&self, budget_ms: f32) -> bool
Returns true if the “frame” span average exceeds budget_ms milliseconds.