pub struct Stft {
pub config: StftConfig,
}Expand description
Short-Time Fourier Transform: sliding-window analysis and synthesis.
Fields
config: StftConfigImplementations
Sourceimpl Stft
impl Stft
pub fn new(config: StftConfig) -> Self
Sourcepub fn analyze(&self, signal: &[f32]) -> Vec<Spectrum>
pub fn analyze(&self, signal: &[f32]) -> Vec<Spectrum>
Analyze a signal into a sequence of Spectrum frames.
Sourcepub fn synthesize(&self, frames: &[Spectrum]) -> Vec<f32>
pub fn synthesize(&self, frames: &[Spectrum]) -> Vec<f32>
Synthesize a signal from STFT frames using overlap-add (OLA).
Sourcepub fn num_frames(&self, signal_len: usize) -> usize
pub fn num_frames(&self, signal_len: usize) -> usize
Number of frames for a signal of given length.
Sourcepub fn frame_time(&self, idx: usize, sample_rate: f32) -> f32
pub fn frame_time(&self, idx: usize, sample_rate: f32) -> f32
Time in seconds of the center of frame idx.