pub struct BoneSkeleton {
pub root: BoneId,
pub ik_chains: Vec<IkChain>,
pub skin_weights: Vec<SkinWeight>,
/* private fields */
}Expand description
The full skeleton — flat map of bones plus hierarchy helpers.
Fields
root: BoneIdik_chains: Vec<IkChain>skin_weights: Vec<SkinWeight>Cached skin weights for the last set of surface points.
Implementations
Sourceimpl BoneSkeleton
impl BoneSkeleton
pub fn new() -> Self
pub fn add_bone( &mut self, name: impl Into<String>, head: Vec3, tail: Vec3, ) -> BoneId
pub fn remove_bone(&mut self, id: BoneId) -> Option<BoneDesc>
pub fn get(&self, id: BoneId) -> Option<&BoneDesc>
pub fn get_mut(&mut self, id: BoneId) -> Option<&mut BoneDesc>
pub fn bones(&self) -> impl Iterator<Item = &BoneDesc>
pub fn bone_count(&self) -> usize
pub fn set_parent(&mut self, child: BoneId, parent: BoneId)
pub fn children_of(&self, id: BoneId) -> &[BoneId]
pub fn ancestors_of(&self, id: BoneId) -> Vec<BoneId>
pub fn depth_of(&self, id: BoneId) -> usize
Sourcepub fn world_head(&self, id: BoneId) -> Vec3
pub fn world_head(&self, id: BoneId) -> Vec3
World-space head of a bone (accumulates parent chain).
Sourcepub fn world_matrix(&self, id: BoneId) -> Mat4
pub fn world_matrix(&self, id: BoneId) -> Mat4
Accumulated world matrix for a bone’s head.
Sourcepub fn bind_weights(&mut self, surface_points: &[Vec3])
pub fn bind_weights(&mut self, surface_points: &[Vec3])
Compute smooth bind weights for a list of surface points.
Sourcepub fn build_humanoid(height: f32) -> Self
pub fn build_humanoid(height: f32) -> Self
Build a standard humanoid skeleton from SDF body proportions.