pub struct AntennaArray {
pub elements: Vec<HertzianDipole>,
pub phase_shifts: Vec<f32>,
}Expand description
An array of Hertzian dipole antennas with programmable phase shifts for beam forming.
Fields
elements: Vec<HertzianDipole>phase_shifts: Vec<f32>Implementations
Sourceimpl AntennaArray
impl AntennaArray
pub fn new(elements: Vec<HertzianDipole>, phase_shifts: Vec<f32>) -> Self
Sourcepub fn uniform_linear(
n: usize,
spacing: f32,
axis: Vec3,
orientation: Vec3,
frequency: f32,
current_moment: f32,
) -> Self
pub fn uniform_linear( n: usize, spacing: f32, axis: Vec3, orientation: Vec3, frequency: f32, current_moment: f32, ) -> Self
Create a uniform linear array along a given axis.
Sourcepub fn array_factor(&self, direction: Vec3) -> f32
pub fn array_factor(&self, direction: Vec3) -> f32
Array factor: AF(direction) = sum_i exp(j*(k*d_i·direction + phase_i)) Returns the magnitude |AF|^2.
Sourcepub fn total_pattern(&self, theta: f32, phi: f32) -> f32
pub fn total_pattern(&self, theta: f32, phi: f32) -> f32
Total radiation pattern: element pattern × array factor.
Sourcepub fn beam_steering(&mut self, target_direction: Vec3)
pub fn beam_steering(&mut self, target_direction: Vec3)
Compute phase shifts to steer the beam toward a target direction.