WeaponPhysicsSystem

Struct WeaponPhysicsSystem 

pub struct WeaponPhysicsSystem {
    pub trail: WeaponTrail,
    pub impacts: Vec<ImpactEffect>,
    pub damage_numbers: DamageNumberManager,
    pub combo_integration: ComboTrailIntegration,
    pub milestone_effects: Vec<ComboMilestoneEffect>,
    pub block_effects: Vec<BlockEffect>,
    pub parry_effect: Option<ParryEffect>,
    pub time_scale: f32,
}
Top-level system that ties together weapon trails, impact effects, damage numbers, and combo integration.

Fields

trail: WeaponTrail

The active weapon trail.

impacts: Vec<ImpactEffect>

Active impact effects.

damage_numbers: DamageNumberManager

Damage number manager (pooled).

combo_integration: ComboTrailIntegration

Combo trail integration.

milestone_effects: Vec<ComboMilestoneEffect>

Active combo milestone effects.

block_effects: Vec<BlockEffect>

Active block effects.

parry_effect: Option<ParryEffect>

Active parry effect (at most one at a time).

time_scale: f32

Global time scale (affected by parry slow-mo).

Implementations

Source

impl WeaponPhysicsSystem

pub fn new(weapon_type: WeaponType) -> Self

Create a new system for the given weapon type.

pub fn switch_weapon(&mut self, weapon_type: WeaponType)

Switch to a different weapon type, resetting the trail.

pub fn begin_swing(&mut self, arc: SwingArc)

Begin a swing with the given arc parameters.

pub fn on_hit( &mut self, contact_point: Vec3, velocity_magnitude: f32, damage: i32, crit: bool, screen_pos: Vec2, hit_direction: Vec3, )

Handle a weapon hitting an entity.

pub fn on_block( &mut self, contact_point: Vec3, attacker_direction: Vec3, velocity_magnitude: f32, )

Handle an attack being blocked.

pub fn on_parry(&mut self, contact_point: Vec3)

Handle a perfect parry.

pub fn update_combo(&mut self, combo_count: u32)

Update the combo count (from the combo tracker).

pub fn update(&mut self, dt: f32)

Tick all systems by dt (real-time).

pub fn trail_vertices(&self) -> Vec<TrailVertex>

Get trail render data for the GPU.