Module partition
proof_
engine
0.1.1
Module partition
Module Items
Functions
In proof_
engine::
graph
proof_engine
::
graph
Module
partition
Functions

kernighan_
lin
Kernighan-Lin refinement: iteratively swap pairs of nodes between partitions to minimize edge cut.
partition_
quality
Partition quality: ratio of edges cut to total edges. Lower is better (fewer inter-partition edges).
recursive_
bisection
Recursive bisection: repeatedly partition each part.
spectral_
partition
Spectral bisection using the Fiedler vector (2nd smallest eigenvector of Laplacian). Nodes with Fiedler value < median go to partition A, rest to partition B.