Trigger

Enum Trigger 

pub enum Trigger {
    JustPressed,
    Held,
    JustReleased,
    EdgeBoth,
}
When an action triggers relative to the key state.

Variants



JustPressed

Fires once on the frame the key was pressed.



Held

Fires every frame the key is held.



JustReleased

Fires once on the frame the key was released.



EdgeBoth

Fires once on JustPressed AND once on JustReleased.