pub struct KeyBindings { /* private fields */ }Expand description
Central key binding registry.
Manages multiple binding groups and provides a unified query interface.
Game systems query actions (not raw keys) each frame via is_active().
Implementations
Sourceimpl KeyBindings
impl KeyBindings
pub fn new() -> Self
Sourcepub fn add_group(&mut self, group: BindingGroup)
pub fn add_group(&mut self, group: BindingGroup)
Add a binding group.
Sourcepub fn set_group_enabled(&mut self, name: &str, enabled: bool)
pub fn set_group_enabled(&mut self, name: &str, enabled: bool)
Enable or disable a named group.
pub fn is_group_enabled(&self, name: &str) -> bool
Sourcepub fn bind(&mut self, action: impl Into<Action>, key: Key)
pub fn bind(&mut self, action: impl Into<Action>, key: Key)
Add a simple key binding to the default (first enabled) group.
Sourcepub fn update(
&mut self,
held: &HashSet<Key>,
just_pressed: &HashSet<Key>,
just_released: &HashSet<Key>,
mouse_delta: (f32, f32),
scroll: f32,
time: f32,
dt: f32,
)
pub fn update( &mut self, held: &HashSet<Key>, just_pressed: &HashSet<Key>, just_released: &HashSet<Key>, mouse_delta: (f32, f32), scroll: f32, time: f32, dt: f32, )
Update internal state from raw input this frame.
Must be called once per frame before any is_active queries.
Sourcepub fn is_active(
&self,
action: &str,
trigger: Trigger,
held: &HashSet<Key>,
just_pressed: &HashSet<Key>,
just_released: &HashSet<Key>,
) -> bool
pub fn is_active( &self, action: &str, trigger: Trigger, held: &HashSet<Key>, just_pressed: &HashSet<Key>, just_released: &HashSet<Key>, ) -> bool
Returns true if the named action is currently active with the given trigger type.
Sourcepub fn just_pressed(
&self,
action: &str,
held: &HashSet<Key>,
just_pressed: &HashSet<Key>,
just_released: &HashSet<Key>,
) -> bool
pub fn just_pressed( &self, action: &str, held: &HashSet<Key>, just_pressed: &HashSet<Key>, just_released: &HashSet<Key>, ) -> bool
Convenience: just pressed.
Sourcepub fn is_held(
&self,
action: &str,
held: &HashSet<Key>,
just_pressed: &HashSet<Key>,
just_released: &HashSet<Key>,
) -> bool
pub fn is_held( &self, action: &str, held: &HashSet<Key>, just_pressed: &HashSet<Key>, just_released: &HashSet<Key>, ) -> bool
Convenience: held.
Sourcepub fn all_actions(&self) -> Vec<&str>
pub fn all_actions(&self) -> Vec<&str>
List all known actions across all groups.
Sourcepub fn display_binding(&self, action: &str) -> Option<&str>
pub fn display_binding(&self, action: &str) -> Option<&str>
Get the display string for the primary binding of an action.
Sourcepub fn chord_just_fired(&self, action: &str) -> bool
pub fn chord_just_fired(&self, action: &str) -> bool
Check if a chord action fired this frame.