pub struct ShadowSystem {
pub config: ShadowConfig,
pub atlas: ShadowAtlas,
pub cascaded_maps: HashMap<LightId, CascadedShadowMap>,
pub omni_maps: HashMap<LightId, OmniShadowMap>,
pub spot_maps: HashMap<LightId, usize>,
pub pcf_kernel: PcfKernel,
pub vsm_maps: HashMap<LightId, VarianceShadowMap>,
pub stats: ShadowStats,
}Expand description
Top-level shadow system that orchestrates shadow map allocation and rendering.
Fields
config: ShadowConfigatlas: ShadowAtlascascaded_maps: HashMap<LightId, CascadedShadowMap>omni_maps: HashMap<LightId, OmniShadowMap>spot_maps: HashMap<LightId, usize>pcf_kernel: PcfKernelvsm_maps: HashMap<LightId, VarianceShadowMap>stats: ShadowStatsStats from the last frame.
Implementations
Sourceimpl ShadowSystem
impl ShadowSystem
pub fn new(config: ShadowConfig) -> Self
Sourcepub fn allocate_for_lights(&mut self, lights: &[(LightId, &Light)])
pub fn allocate_for_lights(&mut self, lights: &[(LightId, &Light)])
Allocate shadow maps for the given shadow-casting lights.
Sourcepub fn shadow_factor(
&self,
light_id: LightId,
world_pos: Vec3,
normal: Vec3,
view_depth: f32,
) -> f32
pub fn shadow_factor( &self, light_id: LightId, world_pos: Vec3, normal: Vec3, view_depth: f32, ) -> f32
Compute the shadow factor for a world point from a specific light.
Sourcepub fn combined_shadow_factor(
&self,
world_pos: Vec3,
normal: Vec3,
view_depth: f32,
) -> f32
pub fn combined_shadow_factor( &self, world_pos: Vec3, normal: Vec3, view_depth: f32, ) -> f32
Compute combined shadow factor from all shadow-casting lights at a point.
Sourcepub fn stats(&self) -> &ShadowStats
pub fn stats(&self) -> &ShadowStats
Get a reference to the current stats.