Netcode Subsystem
Game engine networking: world state snapshots with delta compression, reliable/unreliable transport with fragmentation and bandwidth control, and state synchronization with client-side prediction and server reconciliation.
Re-exports
pub use snapshot::SnapshotId;pub use snapshot::EntitySnapshot;pub use snapshot::ComponentData;pub use snapshot::WorldSnapshot;pub use snapshot::SnapshotDelta;pub use snapshot::EntityDelta;pub use snapshot::ComponentDelta;pub use snapshot::SnapshotRingBuffer;pub use snapshot::RelevancyFilter;pub use snapshot::RelevancyEntry;pub use snapshot::RelevancyRegion;pub use transport::PacketHeader;pub use transport::PacketType;pub use transport::ReliableChannel;pub use transport::UnreliableChannel;pub use transport::PacketFragmenter;pub use transport::FragmentHeader;pub use transport::ReassemblyBuffer;pub use transport::BandwidthThrottle;pub use transport::ConnectionState;pub use transport::ConnectionStateMachine;pub use transport::TransportConfig;pub use transport::TransportStats;pub use sync::InterpolationBuffer;pub use sync::InterpolationSample;pub use sync::PredictionEntry;pub use sync::ClientPrediction;pub use sync::AuthorityModel;pub use sync::AuthorityMode;pub use sync::ReplicatedProperty;pub use sync::PropertyFlags;pub use sync::DirtyTracker;pub use sync::SpawnEvent;pub use sync::DespawnEvent;pub use sync::SpawnDespawnReplicator;pub use sync::ClockSync;pub use sync::ClockSyncSample;pub use sync::SyncState;
Modules
- snapshot
- World state snapshots with delta compression and relevancy filtering.
- sync
- State synchronization: interpolation, prediction, authority, replication, and clock sync.
- transport
- Network transport layer: reliable/unreliable channels, fragmentation, bandwidth throttling, and connection state machine.