pub fn z_function(t: f64) -> f64Expand description
Hardy’s Z-function: real-valued function whose zeros on the real line correspond to zeros of zeta on the critical line. Z(t) = e^{i*theta(t)} * zeta(1/2 + it) where theta(t) is the Riemann-Siegel theta function.