pub enum ParticleForce {
Constant {
force: Vec3,
},
Drag {
coefficient: f32,
},
PointForce {
position: Vec3,
strength: f32,
falloff: Falloff,
},
Turbulence {
strength: f32,
frequency: f32,
octaves: u8,
},
Vortex {
axis: Vec3,
position: Vec3,
strength: f32,
falloff_radius: f32,
},
WindBlast {
direction: Vec3,
min_speed: f32,
max_speed: f32,
gust_freq: f32,
},
KillPlane {
y: f32,
},
Bounce {
normal: Vec3,
d: f32,
restitution: f32,
},
Noise {
amplitude: Vec3,
},
OrbitForce {
center: Vec3,
radius: f32,
strength: f32,
},
}Expand description
A standalone particle force that can be added to a system.
Variants
Constant
Constant directional force (e.g. gravity, wind).
Drag
Drag proportional to velocity.
PointForce
Attractor/repulsor at a point.
Turbulence
Turbulence using layered noise.
Vortex
Vortex spinning around an axis.
WindBlast
Cylindrical wind blast.
KillPlane
Kill particles below a certain Y.
Bounce
Bounce particles off a plane.
Noise
Velocity noise — random jitter per frame.
OrbitForce
Orbit force — pull toward circular orbit.
Implementations
Sourceimpl ParticleForce
impl ParticleForce
Sourcepub fn acceleration(
&self,
p: &MathParticle,
time: f32,
rng: &mut FastRng,
) -> Vec3
pub fn acceleration( &self, p: &MathParticle, time: f32, rng: &mut FastRng, ) -> Vec3
Compute the acceleration this force applies to a particle.