pub struct NavMesh {
pub polys: Vec<NavPoly>,
pub portals: Vec<NavPortal>,
pub area_cost: AreaCost,
/* private fields */
}Expand description
The navigation mesh: a graph of convex polygons connected by portals.
Fields
polys: Vec<NavPoly>portals: Vec<NavPortal>area_cost: AreaCostImplementations
pub fn new() -> Self
pub fn add_poly( &mut self, verts: Vec<Vec2>, area: AreaFlags, cost: f32, ) -> NavPolyId
Sourcepub fn add_portal(
&mut self,
poly_a: NavPolyId,
poly_b: NavPolyId,
left: Vec2,
right: Vec2,
) -> usize
pub fn add_portal( &mut self, poly_a: NavPolyId, poly_b: NavPolyId, left: Vec2, right: Vec2, ) -> usize
Connect two polygons through a shared edge defined by endpoints.
The edge is ordered so that left and right are from the perspective
of standing in poly_a looking into poly_b.
Sourcepub fn build_portals_from_edges(&mut self)
pub fn build_portals_from_edges(&mut self)
Auto-connect all pairs of adjacent polygons that share an edge.
pub fn poly_at_point(&self, p: Vec2) -> Option<NavPolyId>
pub fn poly_by_id(&self, id: NavPolyId) -> Option<&NavPoly>
Sourcepub fn closest_point_on_mesh(&self, p: Vec2) -> NavPoint
pub fn closest_point_on_mesh(&self, p: Vec2) -> NavPoint
Returns the closest point on the navmesh to p.