pub struct AreaLight {
pub position: Vec3,
pub right: Vec3,
pub up: Vec3,
pub color: Vec3,
pub intensity: f32,
}Expand description
Rectangular area light using the Linearly Transformed Cosines (LTC) approach.
Fields
position: Vec3Centre of the rectangle.
right: Vec3Half-extent along the “right” axis (width/2).
up: Vec3Half-extent along the “up” axis (height/2).
color: Vec3intensity: f32Implementations
Sourceimpl AreaLight
impl AreaLight
pub fn new( position: Vec3, right: Vec3, up: Vec3, color: Vec3, intensity: f32, ) -> Self
Sourcepub fn solid_angle_at(&self, pos: Vec3) -> f32
pub fn solid_angle_at(&self, pos: Vec3) -> f32
Approximate the solid angle subtended by the area light at pos.
Sourcepub fn irradiance_at(&self, pos: Vec3, n: Vec3) -> Vec3
pub fn irradiance_at(&self, pos: Vec3, n: Vec3) -> Vec3
Simple irradiance estimate using solid angle and projected area.