pub struct LightProbeGrid {
pub min: Vec3,
pub max: Vec3,
pub resolution: [u32; 3],
pub probes: Vec<Sh3>,
}Expand description
A regular 3D grid of SH3 irradiance probes.
At runtime, shaders can trilinearly interpolate between the 8 nearest probes to get smooth irradiance at any position within the grid bounds.
Fields
min: Vec3World-space AABB minimum corner.
max: Vec3World-space AABB maximum corner.
resolution: [u32; 3]Number of probes along each axis.
probes: Vec<Sh3>Flat probe storage, in x-major order (x + yrx + zrx*ry).
Implementations
Sourceimpl LightProbeGrid
impl LightProbeGrid
Sourcepub fn new(min: Vec3, max: Vec3, resolution: [u32; 3]) -> Self
pub fn new(min: Vec3, max: Vec3, resolution: [u32; 3]) -> Self
Create a grid with all probes initialised to zero.
Sourcepub fn probe_at(&self, ix: usize, iy: usize, iz: usize) -> &Sh3
pub fn probe_at(&self, ix: usize, iy: usize, iz: usize) -> &Sh3
Get a reference to the probe at grid coordinates.
Sourcepub fn probe_at_mut(&mut self, ix: usize, iy: usize, iz: usize) -> &mut Sh3
pub fn probe_at_mut(&mut self, ix: usize, iy: usize, iz: usize) -> &mut Sh3
Get a mutable reference to the probe at grid coordinates.
Sourcepub fn sample(&self, pos: Vec3) -> Sh3
pub fn sample(&self, pos: Vec3) -> Sh3
Trilinearly interpolate SH3 at world-space position pos.
Sourcepub fn compute_ambient(&self, pos: Vec3, normal: Vec3) -> Vec3
pub fn compute_ambient(&self, pos: Vec3, normal: Vec3) -> Vec3
Compute ambient irradiance at pos for a surface with normal.