Pre-built shader graph presets for Proof Engine visual effects.
Each preset is a fully-wired ShaderGraph that produces a distinct visual style. Presets are the primary way game code applies visual effects to the scene.
Pre-built shader graph presets for Proof Engine visual effects.
Each preset is a fully-wired ShaderGraph that produces a distinct visual style. Presets are the primary way game code applies visual effects to the scene.