Graph execution engine: walks sorted passes, manages barriers, GPU timing, triple-buffered frame-in-flight management, async compute overlap detection, execution statistics, and hot-reload from config.
Structs
- Async
Compute Schedule - Identifies passes that can run on the async compute queue, overlapping with graphics work.
- Execution
Stats - Per-frame execution statistics.
- FnPass
Executor - A simple closure-based pass executor.
- Frame
Pacer - Simple frame pacing utility to target a specific framerate.
- Frame
State - State of a single frame in the pipeline.
- Frame
Timeline - Manages triple-buffered frame-in-flight state.
- Graph
Executor - The main execution engine. Walks sorted passes, inserts barriers, tracks timing, and manages resources.
- Multi
Graph Executor - Executes multiple render graphs in sequence (e.g., main scene + UI overlay).
- Pass
Barrier - A barrier that must be issued between two passes.
- Pass
Context - Context provided to each pass during execution. Gives access to input and output resources, resolution info, and pass metadata.
- Pass
Timing Query - Simulated GPU timing query result for a single pass.
Enums
- Barrier
Kind - The kind of GPU barrier inserted between passes.
- Frame
Status
Traits
- Pass
Executor - Trait for pass execution callbacks. Each built-in pass implements this.
Type Aliases
- Boxed
Pass Executor - A boxed pass executor.