pub struct PassDependency {
pub from_pass: String,
pub to_pass: String,
pub resource: String,
pub kind: DependencyKind,
}Expand description
An edge in the render graph, connecting a producer pass to a consumer pass through a shared resource.
Fields
from_pass: Stringto_pass: Stringresource: Stringkind: DependencyKindTrait Implementations
Sourceimpl Clone for PassDependency
impl Clone for PassDependency
Sourcefn clone(&self) -> PassDependency
fn clone(&self) -> PassDependency
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PassDependency
impl Debug for PassDependency