pub struct ShaderVariantCache { /* private fields */ }Expand description
A cache for compiled shader variants, keyed by topology hash.
Implementations
Sourceimpl ShaderVariantCache
impl ShaderVariantCache
pub fn new() -> Self
Sourcepub fn get_or_compile(
&mut self,
graph: &ShaderGraph,
compiler: &ShaderCompiler,
) -> Result<&CompiledShader, CompileError>
pub fn get_or_compile( &mut self, graph: &ShaderGraph, compiler: &ShaderCompiler, ) -> Result<&CompiledShader, CompileError>
Get a cached shader by topology hash, or compile and cache it.
Sourcepub fn invalidate(&mut self, hash: u64)
pub fn invalidate(&mut self, hash: u64)
Invalidate a specific cache entry.