pub fn line_intersection(l1: [f32; 3], l2: [f32; 3]) -> Option<Vec2>Expand description
Compute the intersection of two projective lines. In projective geometry, any two distinct lines always intersect (possibly at infinity). Returns the intersection as an affine point if w != 0, None if the lines are identical.